// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type AllocationStrategy string

// Enum values for AllocationStrategy
const (
	AllocationStrategyPrioritized AllocationStrategy = "Prioritized"
	AllocationStrategyLowestPrice AllocationStrategy = "LowestPrice"
)

// Values returns all known values for AllocationStrategy. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AllocationStrategy) Values() []AllocationStrategy {
	return []AllocationStrategy{
		"Prioritized",
		"LowestPrice",
	}
}

type AsgType string

// Enum values for AsgType
const (
	AsgTypeSingleInstanceType AsgType = "SingleInstanceType"
	AsgTypeMixedInstanceType  AsgType = "MixedInstanceTypes"
)

// Values returns all known values for AsgType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AsgType) Values() []AsgType {
	return []AsgType{
		"SingleInstanceType",
		"MixedInstanceTypes",
	}
}

type AutoScalingConfiguration string

// Enum values for AutoScalingConfiguration
const (
	AutoScalingConfigurationTargetTrackingScalingCpu    AutoScalingConfiguration = "TargetTrackingScalingCpu"
	AutoScalingConfigurationTargetTrackingScalingMemory AutoScalingConfiguration = "TargetTrackingScalingMemory"
)

// Values returns all known values for AutoScalingConfiguration. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutoScalingConfiguration) Values() []AutoScalingConfiguration {
	return []AutoScalingConfiguration{
		"TargetTrackingScalingCpu",
		"TargetTrackingScalingMemory",
	}
}

type CpuVendorArchitecture string

// Enum values for CpuVendorArchitecture
const (
	CpuVendorArchitectureAwsArm64 CpuVendorArchitecture = "AWS_ARM64"
	CpuVendorArchitectureCurrent  CpuVendorArchitecture = "CURRENT"
)

// Values returns all known values for CpuVendorArchitecture. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CpuVendorArchitecture) Values() []CpuVendorArchitecture {
	return []CpuVendorArchitecture{
		"AWS_ARM64",
		"CURRENT",
	}
}

type Currency string

// Enum values for Currency
const (
	CurrencyUsd Currency = "USD"
	CurrencyCny Currency = "CNY"
)

// Values returns all known values for Currency. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Currency) Values() []Currency {
	return []Currency{
		"USD",
		"CNY",
	}
}

type CurrentPerformanceRisk string

// Enum values for CurrentPerformanceRisk
const (
	CurrentPerformanceRiskVeryLow CurrentPerformanceRisk = "VeryLow"
	CurrentPerformanceRiskLow     CurrentPerformanceRisk = "Low"
	CurrentPerformanceRiskMedium  CurrentPerformanceRisk = "Medium"
	CurrentPerformanceRiskHigh    CurrentPerformanceRisk = "High"
)

// Values returns all known values for CurrentPerformanceRisk. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CurrentPerformanceRisk) Values() []CurrentPerformanceRisk {
	return []CurrentPerformanceRisk{
		"VeryLow",
		"Low",
		"Medium",
		"High",
	}
}

type CustomizableMetricHeadroom string

// Enum values for CustomizableMetricHeadroom
const (
	CustomizableMetricHeadroomPercent30 CustomizableMetricHeadroom = "PERCENT_30"
	CustomizableMetricHeadroomPercent20 CustomizableMetricHeadroom = "PERCENT_20"
	CustomizableMetricHeadroomPercent10 CustomizableMetricHeadroom = "PERCENT_10"
	CustomizableMetricHeadroomPercent0  CustomizableMetricHeadroom = "PERCENT_0"
)

// Values returns all known values for CustomizableMetricHeadroom. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CustomizableMetricHeadroom) Values() []CustomizableMetricHeadroom {
	return []CustomizableMetricHeadroom{
		"PERCENT_30",
		"PERCENT_20",
		"PERCENT_10",
		"PERCENT_0",
	}
}

type CustomizableMetricName string

// Enum values for CustomizableMetricName
const (
	CustomizableMetricNameCpuUtilization    CustomizableMetricName = "CpuUtilization"
	CustomizableMetricNameMemoryUtilization CustomizableMetricName = "MemoryUtilization"
)

// Values returns all known values for CustomizableMetricName. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CustomizableMetricName) Values() []CustomizableMetricName {
	return []CustomizableMetricName{
		"CpuUtilization",
		"MemoryUtilization",
	}
}

type CustomizableMetricThreshold string

// Enum values for CustomizableMetricThreshold
const (
	CustomizableMetricThresholdP90  CustomizableMetricThreshold = "P90"
	CustomizableMetricThresholdP95  CustomizableMetricThreshold = "P95"
	CustomizableMetricThresholdP995 CustomizableMetricThreshold = "P99_5"
)

// Values returns all known values for CustomizableMetricThreshold. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CustomizableMetricThreshold) Values() []CustomizableMetricThreshold {
	return []CustomizableMetricThreshold{
		"P90",
		"P95",
		"P99_5",
	}
}

type Dimension string

// Enum values for Dimension
const (
	DimensionSavingsValue              Dimension = "SavingsValue"
	DimensionSavingsValueAfterDiscount Dimension = "SavingsValueAfterDiscount"
)

// Values returns all known values for Dimension. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Dimension) Values() []Dimension {
	return []Dimension{
		"SavingsValue",
		"SavingsValueAfterDiscount",
	}
}

type EBSFilterName string

// Enum values for EBSFilterName
const (
	EBSFilterNameFinding EBSFilterName = "Finding"
)

// Values returns all known values for EBSFilterName. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EBSFilterName) Values() []EBSFilterName {
	return []EBSFilterName{
		"Finding",
	}
}

type EBSFinding string

// Enum values for EBSFinding
const (
	EBSFindingOptimized    EBSFinding = "Optimized"
	EBSFindingNotOptimized EBSFinding = "NotOptimized"
)

// Values returns all known values for EBSFinding. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EBSFinding) Values() []EBSFinding {
	return []EBSFinding{
		"Optimized",
		"NotOptimized",
	}
}

type EBSMetricName string

// Enum values for EBSMetricName
const (
	EBSMetricNameVolumeReadOpsPerSecond    EBSMetricName = "VolumeReadOpsPerSecond"
	EBSMetricNameVolumeWriteOpsPerSecond   EBSMetricName = "VolumeWriteOpsPerSecond"
	EBSMetricNameVolumeReadBytesPerSecond  EBSMetricName = "VolumeReadBytesPerSecond"
	EBSMetricNameVolumeWriteBytesPerSecond EBSMetricName = "VolumeWriteBytesPerSecond"
	EBSMetricNameVolumeIopsExceeded        EBSMetricName = "VolumeIOPSExceeded"
	EBSMetricNameVolumeThroughputExceeded  EBSMetricName = "VolumeThroughputExceeded"
)

// Values returns all known values for EBSMetricName. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EBSMetricName) Values() []EBSMetricName {
	return []EBSMetricName{
		"VolumeReadOpsPerSecond",
		"VolumeWriteOpsPerSecond",
		"VolumeReadBytesPerSecond",
		"VolumeWriteBytesPerSecond",
		"VolumeIOPSExceeded",
		"VolumeThroughputExceeded",
	}
}

type EBSSavingsEstimationModeSource string

// Enum values for EBSSavingsEstimationModeSource
const (
	EBSSavingsEstimationModeSourcePublicPricing           EBSSavingsEstimationModeSource = "PublicPricing"
	EBSSavingsEstimationModeSourceCostExplorerRightsizing EBSSavingsEstimationModeSource = "CostExplorerRightsizing"
	EBSSavingsEstimationModeSourceCostOptimizationHub     EBSSavingsEstimationModeSource = "CostOptimizationHub"
)

// Values returns all known values for EBSSavingsEstimationModeSource. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EBSSavingsEstimationModeSource) Values() []EBSSavingsEstimationModeSource {
	return []EBSSavingsEstimationModeSource{
		"PublicPricing",
		"CostExplorerRightsizing",
		"CostOptimizationHub",
	}
}

type ECSSavingsEstimationModeSource string

// Enum values for ECSSavingsEstimationModeSource
const (
	ECSSavingsEstimationModeSourcePublicPricing           ECSSavingsEstimationModeSource = "PublicPricing"
	ECSSavingsEstimationModeSourceCostExplorerRightsizing ECSSavingsEstimationModeSource = "CostExplorerRightsizing"
	ECSSavingsEstimationModeSourceCostOptimizationHub     ECSSavingsEstimationModeSource = "CostOptimizationHub"
)

// Values returns all known values for ECSSavingsEstimationModeSource. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ECSSavingsEstimationModeSource) Values() []ECSSavingsEstimationModeSource {
	return []ECSSavingsEstimationModeSource{
		"PublicPricing",
		"CostExplorerRightsizing",
		"CostOptimizationHub",
	}
}

type ECSServiceLaunchType string

// Enum values for ECSServiceLaunchType
const (
	ECSServiceLaunchTypeEc2     ECSServiceLaunchType = "EC2"
	ECSServiceLaunchTypeFargate ECSServiceLaunchType = "Fargate"
)

// Values returns all known values for ECSServiceLaunchType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ECSServiceLaunchType) Values() []ECSServiceLaunchType {
	return []ECSServiceLaunchType{
		"EC2",
		"Fargate",
	}
}

type ECSServiceMetricName string

// Enum values for ECSServiceMetricName
const (
	ECSServiceMetricNameCpu    ECSServiceMetricName = "Cpu"
	ECSServiceMetricNameMemory ECSServiceMetricName = "Memory"
)

// Values returns all known values for ECSServiceMetricName. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ECSServiceMetricName) Values() []ECSServiceMetricName {
	return []ECSServiceMetricName{
		"Cpu",
		"Memory",
	}
}

type ECSServiceMetricStatistic string

// Enum values for ECSServiceMetricStatistic
const (
	ECSServiceMetricStatisticMaximum ECSServiceMetricStatistic = "Maximum"
	ECSServiceMetricStatisticAverage ECSServiceMetricStatistic = "Average"
)

// Values returns all known values for ECSServiceMetricStatistic. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ECSServiceMetricStatistic) Values() []ECSServiceMetricStatistic {
	return []ECSServiceMetricStatistic{
		"Maximum",
		"Average",
	}
}

type ECSServiceRecommendationFilterName string

// Enum values for ECSServiceRecommendationFilterName
const (
	ECSServiceRecommendationFilterNameFinding           ECSServiceRecommendationFilterName = "Finding"
	ECSServiceRecommendationFilterNameFindingReasonCode ECSServiceRecommendationFilterName = "FindingReasonCode"
)

// Values returns all known values for ECSServiceRecommendationFilterName. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ECSServiceRecommendationFilterName) Values() []ECSServiceRecommendationFilterName {
	return []ECSServiceRecommendationFilterName{
		"Finding",
		"FindingReasonCode",
	}
}

type ECSServiceRecommendationFinding string

// Enum values for ECSServiceRecommendationFinding
const (
	ECSServiceRecommendationFindingOptimized        ECSServiceRecommendationFinding = "Optimized"
	ECSServiceRecommendationFindingUnderProvisioned ECSServiceRecommendationFinding = "Underprovisioned"
	ECSServiceRecommendationFindingOverProvisioned  ECSServiceRecommendationFinding = "Overprovisioned"
)

// Values returns all known values for ECSServiceRecommendationFinding. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ECSServiceRecommendationFinding) Values() []ECSServiceRecommendationFinding {
	return []ECSServiceRecommendationFinding{
		"Optimized",
		"Underprovisioned",
		"Overprovisioned",
	}
}

type ECSServiceRecommendationFindingReasonCode string

// Enum values for ECSServiceRecommendationFindingReasonCode
const (
	ECSServiceRecommendationFindingReasonCodeMemoryOverProvisioned  ECSServiceRecommendationFindingReasonCode = "MemoryOverprovisioned"
	ECSServiceRecommendationFindingReasonCodeMemoryUnderProvisioned ECSServiceRecommendationFindingReasonCode = "MemoryUnderprovisioned"
	ECSServiceRecommendationFindingReasonCodeCpuOverProvisioned     ECSServiceRecommendationFindingReasonCode = "CPUOverprovisioned"
	ECSServiceRecommendationFindingReasonCodeCpuUnderProvisioned    ECSServiceRecommendationFindingReasonCode = "CPUUnderprovisioned"
)

// Values returns all known values for ECSServiceRecommendationFindingReasonCode.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ECSServiceRecommendationFindingReasonCode) Values() []ECSServiceRecommendationFindingReasonCode {
	return []ECSServiceRecommendationFindingReasonCode{
		"MemoryOverprovisioned",
		"MemoryUnderprovisioned",
		"CPUOverprovisioned",
		"CPUUnderprovisioned",
	}
}

type EnhancedInfrastructureMetrics string

// Enum values for EnhancedInfrastructureMetrics
const (
	EnhancedInfrastructureMetricsActive   EnhancedInfrastructureMetrics = "Active"
	EnhancedInfrastructureMetricsInactive EnhancedInfrastructureMetrics = "Inactive"
)

// Values returns all known values for EnhancedInfrastructureMetrics. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EnhancedInfrastructureMetrics) Values() []EnhancedInfrastructureMetrics {
	return []EnhancedInfrastructureMetrics{
		"Active",
		"Inactive",
	}
}

type EnrollmentFilterName string

// Enum values for EnrollmentFilterName
const (
	EnrollmentFilterNameStatus EnrollmentFilterName = "Status"
)

// Values returns all known values for EnrollmentFilterName. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EnrollmentFilterName) Values() []EnrollmentFilterName {
	return []EnrollmentFilterName{
		"Status",
	}
}

type ExportableAutoScalingGroupField string

// Enum values for ExportableAutoScalingGroupField
const (
	ExportableAutoScalingGroupFieldAccountId                                                                  ExportableAutoScalingGroupField = "AccountId"
	ExportableAutoScalingGroupFieldAutoScalingGroupArn                                                        ExportableAutoScalingGroupField = "AutoScalingGroupArn"
	ExportableAutoScalingGroupFieldAutoScalingGroupName                                                       ExportableAutoScalingGroupField = "AutoScalingGroupName"
	ExportableAutoScalingGroupFieldFinding                                                                    ExportableAutoScalingGroupField = "Finding"
	ExportableAutoScalingGroupFieldUtilizationMetricsCpuMaximum                                               ExportableAutoScalingGroupField = "UtilizationMetricsCpuMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsMemoryMaximum                                            ExportableAutoScalingGroupField = "UtilizationMetricsMemoryMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsEbsReadOpsPerSecondMaximum                               ExportableAutoScalingGroupField = "UtilizationMetricsEbsReadOpsPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsEbsWriteOpsPerSecondMaximum                              ExportableAutoScalingGroupField = "UtilizationMetricsEbsWriteOpsPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsEbsReadBytesPerSecondMaximum                             ExportableAutoScalingGroupField = "UtilizationMetricsEbsReadBytesPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsEbsWriteBytesPerSecondMaximum                            ExportableAutoScalingGroupField = "UtilizationMetricsEbsWriteBytesPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsDiskReadOpsPerSecondMaximum                              ExportableAutoScalingGroupField = "UtilizationMetricsDiskReadOpsPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsDiskWriteOpsPerSecondMaximum                             ExportableAutoScalingGroupField = "UtilizationMetricsDiskWriteOpsPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsDiskReadBytesPerSecondMaximum                            ExportableAutoScalingGroupField = "UtilizationMetricsDiskReadBytesPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsDiskWriteBytesPerSecondMaximum                           ExportableAutoScalingGroupField = "UtilizationMetricsDiskWriteBytesPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsNetworkInBytesPerSecondMaximum                           ExportableAutoScalingGroupField = "UtilizationMetricsNetworkInBytesPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsNetworkOutBytesPerSecondMaximum                          ExportableAutoScalingGroupField = "UtilizationMetricsNetworkOutBytesPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsNetworkPacketsInPerSecondMaximum                         ExportableAutoScalingGroupField = "UtilizationMetricsNetworkPacketsInPerSecondMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsNetworkPacketsOutPerSecondMaximum                        ExportableAutoScalingGroupField = "UtilizationMetricsNetworkPacketsOutPerSecondMaximum"
	ExportableAutoScalingGroupFieldLookbackPeriodInDays                                                       ExportableAutoScalingGroupField = "LookbackPeriodInDays"
	ExportableAutoScalingGroupFieldCurrentConfigurationInstanceType                                           ExportableAutoScalingGroupField = "CurrentConfigurationInstanceType"
	ExportableAutoScalingGroupFieldCurrentConfigurationDesiredCapacity                                        ExportableAutoScalingGroupField = "CurrentConfigurationDesiredCapacity"
	ExportableAutoScalingGroupFieldCurrentConfigurationMinSize                                                ExportableAutoScalingGroupField = "CurrentConfigurationMinSize"
	ExportableAutoScalingGroupFieldCurrentConfigurationMaxSize                                                ExportableAutoScalingGroupField = "CurrentConfigurationMaxSize"
	ExportableAutoScalingGroupFieldCurrentConfigurationAllocationStrategy                                     ExportableAutoScalingGroupField = "CurrentConfigurationAllocationStrategy"
	ExportableAutoScalingGroupFieldCurrentConfigurationMixedInstanceTypes                                     ExportableAutoScalingGroupField = "CurrentConfigurationMixedInstanceTypes"
	ExportableAutoScalingGroupFieldCurrentConfigurationType                                                   ExportableAutoScalingGroupField = "CurrentConfigurationType"
	ExportableAutoScalingGroupFieldCurrentOnDemandPrice                                                       ExportableAutoScalingGroupField = "CurrentOnDemandPrice"
	ExportableAutoScalingGroupFieldCurrentStandardOneYearNoUpfrontReservedPrice                               ExportableAutoScalingGroupField = "CurrentStandardOneYearNoUpfrontReservedPrice"
	ExportableAutoScalingGroupFieldCurrentStandardThreeYearNoUpfrontReservedPrice                             ExportableAutoScalingGroupField = "CurrentStandardThreeYearNoUpfrontReservedPrice"
	ExportableAutoScalingGroupFieldCurrentVcpus                                                               ExportableAutoScalingGroupField = "CurrentVCpus"
	ExportableAutoScalingGroupFieldCurrentMemory                                                              ExportableAutoScalingGroupField = "CurrentMemory"
	ExportableAutoScalingGroupFieldCurrentStorage                                                             ExportableAutoScalingGroupField = "CurrentStorage"
	ExportableAutoScalingGroupFieldCurrentNetwork                                                             ExportableAutoScalingGroupField = "CurrentNetwork"
	ExportableAutoScalingGroupFieldRecommendationOptionsConfigurationInstanceType                             ExportableAutoScalingGroupField = "RecommendationOptionsConfigurationInstanceType"
	ExportableAutoScalingGroupFieldRecommendationOptionsConfigurationDesiredCapacity                          ExportableAutoScalingGroupField = "RecommendationOptionsConfigurationDesiredCapacity"
	ExportableAutoScalingGroupFieldRecommendationOptionsConfigurationMinSize                                  ExportableAutoScalingGroupField = "RecommendationOptionsConfigurationMinSize"
	ExportableAutoScalingGroupFieldRecommendationOptionsConfigurationMaxSize                                  ExportableAutoScalingGroupField = "RecommendationOptionsConfigurationMaxSize"
	ExportableAutoScalingGroupFieldRecommendationOptionsConfigurationEstimatedInstanceHourReductionPercentage ExportableAutoScalingGroupField = "RecommendationOptionsConfigurationEstimatedInstanceHourReductionPercentage"
	ExportableAutoScalingGroupFieldRecommendationOptionsConfigurationAllocationStrategy                       ExportableAutoScalingGroupField = "RecommendationOptionsConfigurationAllocationStrategy"
	ExportableAutoScalingGroupFieldRecommendationOptionsConfigurationMixedInstanceTypes                       ExportableAutoScalingGroupField = "RecommendationOptionsConfigurationMixedInstanceTypes"
	ExportableAutoScalingGroupFieldRecommendationOptionsConfigurationType                                     ExportableAutoScalingGroupField = "RecommendationOptionsConfigurationType"
	ExportableAutoScalingGroupFieldRecommendationOptionsProjectedUtilizationMetricsCpuMaximum                 ExportableAutoScalingGroupField = "RecommendationOptionsProjectedUtilizationMetricsCpuMaximum"
	ExportableAutoScalingGroupFieldRecommendationOptionsProjectedUtilizationMetricsMemoryMaximum              ExportableAutoScalingGroupField = "RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum"
	ExportableAutoScalingGroupFieldRecommendationOptionsPerformanceRisk                                       ExportableAutoScalingGroupField = "RecommendationOptionsPerformanceRisk"
	ExportableAutoScalingGroupFieldRecommendationOptionsOnDemandPrice                                         ExportableAutoScalingGroupField = "RecommendationOptionsOnDemandPrice"
	ExportableAutoScalingGroupFieldRecommendationOptionsStandardOneYearNoUpfrontReservedPrice                 ExportableAutoScalingGroupField = "RecommendationOptionsStandardOneYearNoUpfrontReservedPrice"
	ExportableAutoScalingGroupFieldRecommendationOptionsStandardThreeYearNoUpfrontReservedPrice               ExportableAutoScalingGroupField = "RecommendationOptionsStandardThreeYearNoUpfrontReservedPrice"
	ExportableAutoScalingGroupFieldRecommendationOptionsVcpus                                                 ExportableAutoScalingGroupField = "RecommendationOptionsVcpus"
	ExportableAutoScalingGroupFieldRecommendationOptionsMemory                                                ExportableAutoScalingGroupField = "RecommendationOptionsMemory"
	ExportableAutoScalingGroupFieldRecommendationOptionsStorage                                               ExportableAutoScalingGroupField = "RecommendationOptionsStorage"
	ExportableAutoScalingGroupFieldRecommendationOptionsNetwork                                               ExportableAutoScalingGroupField = "RecommendationOptionsNetwork"
	ExportableAutoScalingGroupFieldLastRefreshTimestamp                                                       ExportableAutoScalingGroupField = "LastRefreshTimestamp"
	ExportableAutoScalingGroupFieldCurrentPerformanceRisk                                                     ExportableAutoScalingGroupField = "CurrentPerformanceRisk"
	ExportableAutoScalingGroupFieldRecommendationOptionsSavingsOpportunityPercentage                          ExportableAutoScalingGroupField = "RecommendationOptionsSavingsOpportunityPercentage"
	ExportableAutoScalingGroupFieldRecommendationOptionsEstimatedMonthlySavingsCurrency                       ExportableAutoScalingGroupField = "RecommendationOptionsEstimatedMonthlySavingsCurrency"
	ExportableAutoScalingGroupFieldRecommendationOptionsEstimatedMonthlySavingsValue                          ExportableAutoScalingGroupField = "RecommendationOptionsEstimatedMonthlySavingsValue"
	ExportableAutoScalingGroupFieldEffectiveRecommendationPreferencesCpuVendorArchitectures                   ExportableAutoScalingGroupField = "EffectiveRecommendationPreferencesCpuVendorArchitectures"
	ExportableAutoScalingGroupFieldEffectiveRecommendationPreferencesEnhancedInfrastructureMetrics            ExportableAutoScalingGroupField = "EffectiveRecommendationPreferencesEnhancedInfrastructureMetrics"
	ExportableAutoScalingGroupFieldEffectiveRecommendationPreferencesInferredWorkloadTypes                    ExportableAutoScalingGroupField = "EffectiveRecommendationPreferencesInferredWorkloadTypes"
	ExportableAutoScalingGroupFieldEffectiveRecommendationPreferencesPreferredResources                       ExportableAutoScalingGroupField = "EffectiveRecommendationPreferencesPreferredResources"
	ExportableAutoScalingGroupFieldEffectiveRecommendationPreferencesLookbackPeriod                           ExportableAutoScalingGroupField = "EffectiveRecommendationPreferencesLookBackPeriod"
	ExportableAutoScalingGroupFieldInferredWorkloadTypes                                                      ExportableAutoScalingGroupField = "InferredWorkloadTypes"
	ExportableAutoScalingGroupFieldRecommendationOptionsMigrationEffort                                       ExportableAutoScalingGroupField = "RecommendationOptionsMigrationEffort"
	ExportableAutoScalingGroupFieldCurrentInstanceGpuInfo                                                     ExportableAutoScalingGroupField = "CurrentInstanceGpuInfo"
	ExportableAutoScalingGroupFieldRecommendationOptionsInstanceGpuInfo                                       ExportableAutoScalingGroupField = "RecommendationOptionsInstanceGpuInfo"
	ExportableAutoScalingGroupFieldUtilizationMetricsGpuPercentageMaximum                                     ExportableAutoScalingGroupField = "UtilizationMetricsGpuPercentageMaximum"
	ExportableAutoScalingGroupFieldUtilizationMetricsGpuMemoryPercentageMaximum                               ExportableAutoScalingGroupField = "UtilizationMetricsGpuMemoryPercentageMaximum"
	ExportableAutoScalingGroupFieldRecommendationOptionsProjectedUtilizationMetricsGpuMaximum                 ExportableAutoScalingGroupField = "RecommendationOptionsProjectedUtilizationMetricsGpuPercentageMaximum"
	ExportableAutoScalingGroupFieldRecommendationOptionsProjectedUtilizationMetricsGpuMemoryMaximum           ExportableAutoScalingGroupField = "RecommendationOptionsProjectedUtilizationMetricsGpuMemoryPercentageMaximum"
	ExportableAutoScalingGroupFieldEffectiveRecommendationPreferencesSavingsEstimationMode                    ExportableAutoScalingGroupField = "EffectiveRecommendationPreferencesSavingsEstimationMode"
	ExportableAutoScalingGroupFieldRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage            ExportableAutoScalingGroupField = "RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage"
	ExportableAutoScalingGroupFieldRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts         ExportableAutoScalingGroupField = "RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts"
	ExportableAutoScalingGroupFieldRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts            ExportableAutoScalingGroupField = "RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts"
)

// Values returns all known values for ExportableAutoScalingGroupField. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExportableAutoScalingGroupField) Values() []ExportableAutoScalingGroupField {
	return []ExportableAutoScalingGroupField{
		"AccountId",
		"AutoScalingGroupArn",
		"AutoScalingGroupName",
		"Finding",
		"UtilizationMetricsCpuMaximum",
		"UtilizationMetricsMemoryMaximum",
		"UtilizationMetricsEbsReadOpsPerSecondMaximum",
		"UtilizationMetricsEbsWriteOpsPerSecondMaximum",
		"UtilizationMetricsEbsReadBytesPerSecondMaximum",
		"UtilizationMetricsEbsWriteBytesPerSecondMaximum",
		"UtilizationMetricsDiskReadOpsPerSecondMaximum",
		"UtilizationMetricsDiskWriteOpsPerSecondMaximum",
		"UtilizationMetricsDiskReadBytesPerSecondMaximum",
		"UtilizationMetricsDiskWriteBytesPerSecondMaximum",
		"UtilizationMetricsNetworkInBytesPerSecondMaximum",
		"UtilizationMetricsNetworkOutBytesPerSecondMaximum",
		"UtilizationMetricsNetworkPacketsInPerSecondMaximum",
		"UtilizationMetricsNetworkPacketsOutPerSecondMaximum",
		"LookbackPeriodInDays",
		"CurrentConfigurationInstanceType",
		"CurrentConfigurationDesiredCapacity",
		"CurrentConfigurationMinSize",
		"CurrentConfigurationMaxSize",
		"CurrentConfigurationAllocationStrategy",
		"CurrentConfigurationMixedInstanceTypes",
		"CurrentConfigurationType",
		"CurrentOnDemandPrice",
		"CurrentStandardOneYearNoUpfrontReservedPrice",
		"CurrentStandardThreeYearNoUpfrontReservedPrice",
		"CurrentVCpus",
		"CurrentMemory",
		"CurrentStorage",
		"CurrentNetwork",
		"RecommendationOptionsConfigurationInstanceType",
		"RecommendationOptionsConfigurationDesiredCapacity",
		"RecommendationOptionsConfigurationMinSize",
		"RecommendationOptionsConfigurationMaxSize",
		"RecommendationOptionsConfigurationEstimatedInstanceHourReductionPercentage",
		"RecommendationOptionsConfigurationAllocationStrategy",
		"RecommendationOptionsConfigurationMixedInstanceTypes",
		"RecommendationOptionsConfigurationType",
		"RecommendationOptionsProjectedUtilizationMetricsCpuMaximum",
		"RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum",
		"RecommendationOptionsPerformanceRisk",
		"RecommendationOptionsOnDemandPrice",
		"RecommendationOptionsStandardOneYearNoUpfrontReservedPrice",
		"RecommendationOptionsStandardThreeYearNoUpfrontReservedPrice",
		"RecommendationOptionsVcpus",
		"RecommendationOptionsMemory",
		"RecommendationOptionsStorage",
		"RecommendationOptionsNetwork",
		"LastRefreshTimestamp",
		"CurrentPerformanceRisk",
		"RecommendationOptionsSavingsOpportunityPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrency",
		"RecommendationOptionsEstimatedMonthlySavingsValue",
		"EffectiveRecommendationPreferencesCpuVendorArchitectures",
		"EffectiveRecommendationPreferencesEnhancedInfrastructureMetrics",
		"EffectiveRecommendationPreferencesInferredWorkloadTypes",
		"EffectiveRecommendationPreferencesPreferredResources",
		"EffectiveRecommendationPreferencesLookBackPeriod",
		"InferredWorkloadTypes",
		"RecommendationOptionsMigrationEffort",
		"CurrentInstanceGpuInfo",
		"RecommendationOptionsInstanceGpuInfo",
		"UtilizationMetricsGpuPercentageMaximum",
		"UtilizationMetricsGpuMemoryPercentageMaximum",
		"RecommendationOptionsProjectedUtilizationMetricsGpuPercentageMaximum",
		"RecommendationOptionsProjectedUtilizationMetricsGpuMemoryPercentageMaximum",
		"EffectiveRecommendationPreferencesSavingsEstimationMode",
		"RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts",
		"RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts",
	}
}

type ExportableECSServiceField string

// Enum values for ExportableECSServiceField
const (
	ExportableECSServiceFieldAccountId                                                          ExportableECSServiceField = "AccountId"
	ExportableECSServiceFieldServiceArn                                                         ExportableECSServiceField = "ServiceArn"
	ExportableECSServiceFieldLookbackPeriodInDays                                               ExportableECSServiceField = "LookbackPeriodInDays"
	ExportableECSServiceFieldLastRefreshTimestamp                                               ExportableECSServiceField = "LastRefreshTimestamp"
	ExportableECSServiceFieldLaunchType                                                         ExportableECSServiceField = "LaunchType"
	ExportableECSServiceFieldCurrentPerformanceRisk                                             ExportableECSServiceField = "CurrentPerformanceRisk"
	ExportableECSServiceFieldCurrentServiceConfigurationMemory                                  ExportableECSServiceField = "CurrentServiceConfigurationMemory"
	ExportableECSServiceFieldCurrentServiceConfigurationCpu                                     ExportableECSServiceField = "CurrentServiceConfigurationCpu"
	ExportableECSServiceFieldCurrentServiceConfigurationTaskDefinitionArn                       ExportableECSServiceField = "CurrentServiceConfigurationTaskDefinitionArn"
	ExportableECSServiceFieldCurrentServiceConfigurationAutoScalingConfiguration                ExportableECSServiceField = "CurrentServiceConfigurationAutoScalingConfiguration"
	ExportableECSServiceFieldCurrentServiceContainerConfigurations                              ExportableECSServiceField = "CurrentServiceContainerConfigurations"
	ExportableECSServiceFieldUtilizationMetricsCpuMaximum                                       ExportableECSServiceField = "UtilizationMetricsCpuMaximum"
	ExportableECSServiceFieldUtilizationMetricsMemoryMaximum                                    ExportableECSServiceField = "UtilizationMetricsMemoryMaximum"
	ExportableECSServiceFieldFinding                                                            ExportableECSServiceField = "Finding"
	ExportableECSServiceFieldFindingReasonCodes                                                 ExportableECSServiceField = "FindingReasonCodes"
	ExportableECSServiceFieldRecommendationOptionsMemory                                        ExportableECSServiceField = "RecommendationOptionsMemory"
	ExportableECSServiceFieldRecommendationOptionsCpu                                           ExportableECSServiceField = "RecommendationOptionsCpu"
	ExportableECSServiceFieldRecommendationOptionsSavingsOpportunityPercentage                  ExportableECSServiceField = "RecommendationOptionsSavingsOpportunityPercentage"
	ExportableECSServiceFieldRecommendationOptionsEstimatedMonthlySavingsCurrency               ExportableECSServiceField = "RecommendationOptionsEstimatedMonthlySavingsCurrency"
	ExportableECSServiceFieldRecommendationOptionsEstimatedMonthlySavingsValue                  ExportableECSServiceField = "RecommendationOptionsEstimatedMonthlySavingsValue"
	ExportableECSServiceFieldRecommendationOptionsContainerRecommendations                      ExportableECSServiceField = "RecommendationOptionsContainerRecommendations"
	ExportableECSServiceFieldRecommendationOptionsProjectedUtilizationMetricsCpuMaximum         ExportableECSServiceField = "RecommendationOptionsProjectedUtilizationMetricsCpuMaximum"
	ExportableECSServiceFieldRecommendationOptionsProjectedUtilizationMetricsMemoryMaximum      ExportableECSServiceField = "RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum"
	ExportableECSServiceFieldTags                                                               ExportableECSServiceField = "Tags"
	ExportableECSServiceFieldEffectiveRecommendationPreferencesSavingsEstimationMode            ExportableECSServiceField = "EffectiveRecommendationPreferencesSavingsEstimationMode"
	ExportableECSServiceFieldRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage    ExportableECSServiceField = "RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage"
	ExportableECSServiceFieldRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts ExportableECSServiceField = "RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts"
	ExportableECSServiceFieldRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts    ExportableECSServiceField = "RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts"
	ExportableECSServiceFieldEffectiveRecommendationPreferencesLookbackPeriod                   ExportableECSServiceField = "EffectiveRecommendationPreferencesLookBackPeriod"
)

// Values returns all known values for ExportableECSServiceField. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExportableECSServiceField) Values() []ExportableECSServiceField {
	return []ExportableECSServiceField{
		"AccountId",
		"ServiceArn",
		"LookbackPeriodInDays",
		"LastRefreshTimestamp",
		"LaunchType",
		"CurrentPerformanceRisk",
		"CurrentServiceConfigurationMemory",
		"CurrentServiceConfigurationCpu",
		"CurrentServiceConfigurationTaskDefinitionArn",
		"CurrentServiceConfigurationAutoScalingConfiguration",
		"CurrentServiceContainerConfigurations",
		"UtilizationMetricsCpuMaximum",
		"UtilizationMetricsMemoryMaximum",
		"Finding",
		"FindingReasonCodes",
		"RecommendationOptionsMemory",
		"RecommendationOptionsCpu",
		"RecommendationOptionsSavingsOpportunityPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrency",
		"RecommendationOptionsEstimatedMonthlySavingsValue",
		"RecommendationOptionsContainerRecommendations",
		"RecommendationOptionsProjectedUtilizationMetricsCpuMaximum",
		"RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum",
		"Tags",
		"EffectiveRecommendationPreferencesSavingsEstimationMode",
		"RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts",
		"RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts",
		"EffectiveRecommendationPreferencesLookBackPeriod",
	}
}

type ExportableIdleField string

// Enum values for ExportableIdleField
const (
	ExportableIdleFieldAccountId                                         ExportableIdleField = "AccountId"
	ExportableIdleFieldResourceArn                                       ExportableIdleField = "ResourceArn"
	ExportableIdleFieldResourceId                                        ExportableIdleField = "ResourceId"
	ExportableIdleFieldResourceType                                      ExportableIdleField = "ResourceType"
	ExportableIdleFieldLastRefreshTimestamp                              ExportableIdleField = "LastRefreshTimestamp"
	ExportableIdleFieldLookbackPeriodInDays                              ExportableIdleField = "LookbackPeriodInDays"
	ExportableIdleFieldSavingsOpportunity                                ExportableIdleField = "SavingsOpportunity"
	ExportableIdleFieldSavingsOpportunityAfterDiscount                   ExportableIdleField = "SavingsOpportunityAfterDiscount"
	ExportableIdleFieldUtilizationMetricsCpuMaximum                      ExportableIdleField = "UtilizationMetricsCpuMaximum"
	ExportableIdleFieldUtilizationMetricsMemoryMaximum                   ExportableIdleField = "UtilizationMetricsMemoryMaximum"
	ExportableIdleFieldUtilizationMetricsNetworkOutBytesPerSecondMaximum ExportableIdleField = "UtilizationMetricsNetworkOutBytesPerSecondMaximum"
	ExportableIdleFieldUtilizationMetricsNetworkInBytesPerSecondMaximum  ExportableIdleField = "UtilizationMetricsNetworkInBytesPerSecondMaximum"
	ExportableIdleFieldUtilizationMetricsDatabaseConnectionsMaximum      ExportableIdleField = "UtilizationMetricsDatabaseConnectionsMaximum"
	ExportableIdleFieldUtilizationMetricsEbsVolumeReadIopsMaximum        ExportableIdleField = "UtilizationMetricsEBSVolumeReadIOPSMaximum"
	ExportableIdleFieldUtilizationMetricsEbsVolumeWriteIopsMaximum       ExportableIdleField = "UtilizationMetricsEBSVolumeWriteIOPSMaximum"
	ExportableIdleFieldUtilizationMetricsVolumeReadOpsPerSecondMaximum   ExportableIdleField = "UtilizationMetricsVolumeReadOpsPerSecondMaximum"
	ExportableIdleFieldUtilizationMetricsVolumeWriteOpsPerSecondMaximum  ExportableIdleField = "UtilizationMetricsVolumeWriteOpsPerSecondMaximum"
	ExportableIdleFieldUtilizationMetricsActiveConnectionCountMaximum    ExportableIdleField = "UtilizationMetricsActiveConnectionCountMaximum"
	ExportableIdleFieldUtilizationMetricsPacketsInFromSourceMaximum      ExportableIdleField = "UtilizationMetricsPacketsInFromSourceMaximum"
	ExportableIdleFieldUtilizationMetricsPacketsInFromDestinationMaximum ExportableIdleField = "UtilizationMetricsPacketsInFromDestinationMaximum"
	ExportableIdleFieldUtilizationMetricsConsumedReadCapacityUnitsSum    ExportableIdleField = "UtilizationMetricsConsumedReadCapacityUnitsSum"
	ExportableIdleFieldUtilizationMetricsConsumedWriteCapacityUnitsSum   ExportableIdleField = "UtilizationMetricsConsumedWriteCapacityUnitsSum"
	ExportableIdleFieldUtilizationMetricsNewConnectionsSum               ExportableIdleField = "UtilizationMetricsNewConnectionsSum"
	ExportableIdleFieldUtilizationMetricsEngineCpuUtilizationMaximum     ExportableIdleField = "UtilizationMetricsEngineCPUUtilizationMaximum"
	ExportableIdleFieldUtilizationMetricsCacheHitsSum                    ExportableIdleField = "UtilizationMetricsCacheHitsSum"
	ExportableIdleFieldUtilizationMetricsCacheMissesSum                  ExportableIdleField = "UtilizationMetricsCacheMissesSum"
	ExportableIdleFieldUtilizationMetricsKeyspaceHitsSum                 ExportableIdleField = "UtilizationMetricsKeyspaceHitsSum"
	ExportableIdleFieldUtilizationMetricsKeyspaceMissesSum               ExportableIdleField = "UtilizationMetricsKeyspaceMissesSum"
	ExportableIdleFieldUtilizationMetricsIsIdleMinimum                   ExportableIdleField = "UtilizationMetricsIsIdleMinimum"
	ExportableIdleFieldUtilizationMetricsUserConnectedSum                ExportableIdleField = "UtilizationMetricsUserConnectedSum"
	ExportableIdleFieldUtilizationMetricsInvocationsSum                  ExportableIdleField = "UtilizationMetricsInvocationsSum"
	ExportableIdleFieldUtilizationMetricsGetTypeCmdsSum                  ExportableIdleField = "UtilizationMetricsGetTypeCmdsSum"
	ExportableIdleFieldUtilizationMetricsSetTypeCmdsSum                  ExportableIdleField = "UtilizationMetricsSetTypeCmdsSum"
	ExportableIdleFieldUtilizationMetricsElastiCacheProcessingUnitsSum   ExportableIdleField = "UtilizationMetricsElastiCacheProcessingUnitsSum"
	ExportableIdleFieldUtilizationMetricsCurrConnectionsSum              ExportableIdleField = "UtilizationMetricsCurrConnectionsSum"
	ExportableIdleFieldUtilizationMetricsDatabaseConnectionsSum          ExportableIdleField = "UtilizationMetricsDatabaseConnectionsSum"
	ExportableIdleFieldFinding                                           ExportableIdleField = "Finding"
	ExportableIdleFieldFindingDescription                                ExportableIdleField = "FindingDescription"
	ExportableIdleFieldTags                                              ExportableIdleField = "Tags"
)

// Values returns all known values for ExportableIdleField. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExportableIdleField) Values() []ExportableIdleField {
	return []ExportableIdleField{
		"AccountId",
		"ResourceArn",
		"ResourceId",
		"ResourceType",
		"LastRefreshTimestamp",
		"LookbackPeriodInDays",
		"SavingsOpportunity",
		"SavingsOpportunityAfterDiscount",
		"UtilizationMetricsCpuMaximum",
		"UtilizationMetricsMemoryMaximum",
		"UtilizationMetricsNetworkOutBytesPerSecondMaximum",
		"UtilizationMetricsNetworkInBytesPerSecondMaximum",
		"UtilizationMetricsDatabaseConnectionsMaximum",
		"UtilizationMetricsEBSVolumeReadIOPSMaximum",
		"UtilizationMetricsEBSVolumeWriteIOPSMaximum",
		"UtilizationMetricsVolumeReadOpsPerSecondMaximum",
		"UtilizationMetricsVolumeWriteOpsPerSecondMaximum",
		"UtilizationMetricsActiveConnectionCountMaximum",
		"UtilizationMetricsPacketsInFromSourceMaximum",
		"UtilizationMetricsPacketsInFromDestinationMaximum",
		"UtilizationMetricsConsumedReadCapacityUnitsSum",
		"UtilizationMetricsConsumedWriteCapacityUnitsSum",
		"UtilizationMetricsNewConnectionsSum",
		"UtilizationMetricsEngineCPUUtilizationMaximum",
		"UtilizationMetricsCacheHitsSum",
		"UtilizationMetricsCacheMissesSum",
		"UtilizationMetricsKeyspaceHitsSum",
		"UtilizationMetricsKeyspaceMissesSum",
		"UtilizationMetricsIsIdleMinimum",
		"UtilizationMetricsUserConnectedSum",
		"UtilizationMetricsInvocationsSum",
		"UtilizationMetricsGetTypeCmdsSum",
		"UtilizationMetricsSetTypeCmdsSum",
		"UtilizationMetricsElastiCacheProcessingUnitsSum",
		"UtilizationMetricsCurrConnectionsSum",
		"UtilizationMetricsDatabaseConnectionsSum",
		"Finding",
		"FindingDescription",
		"Tags",
	}
}

type ExportableInstanceField string

// Enum values for ExportableInstanceField
const (
	ExportableInstanceFieldAccountId                                                                  ExportableInstanceField = "AccountId"
	ExportableInstanceFieldInstanceArn                                                                ExportableInstanceField = "InstanceArn"
	ExportableInstanceFieldInstanceName                                                               ExportableInstanceField = "InstanceName"
	ExportableInstanceFieldFinding                                                                    ExportableInstanceField = "Finding"
	ExportableInstanceFieldFindingReasonCodes                                                         ExportableInstanceField = "FindingReasonCodes"
	ExportableInstanceFieldLookbackPeriodInDays                                                       ExportableInstanceField = "LookbackPeriodInDays"
	ExportableInstanceFieldCurrentInstanceType                                                        ExportableInstanceField = "CurrentInstanceType"
	ExportableInstanceFieldUtilizationMetricsCpuMaximum                                               ExportableInstanceField = "UtilizationMetricsCpuMaximum"
	ExportableInstanceFieldUtilizationMetricsMemoryMaximum                                            ExportableInstanceField = "UtilizationMetricsMemoryMaximum"
	ExportableInstanceFieldUtilizationMetricsEbsReadOpsPerSecondMaximum                               ExportableInstanceField = "UtilizationMetricsEbsReadOpsPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsEbsWriteOpsPerSecondMaximum                              ExportableInstanceField = "UtilizationMetricsEbsWriteOpsPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsEbsReadBytesPerSecondMaximum                             ExportableInstanceField = "UtilizationMetricsEbsReadBytesPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsEbsWriteBytesPerSecondMaximum                            ExportableInstanceField = "UtilizationMetricsEbsWriteBytesPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsDiskReadOpsPerSecondMaximum                              ExportableInstanceField = "UtilizationMetricsDiskReadOpsPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsDiskWriteOpsPerSecondMaximum                             ExportableInstanceField = "UtilizationMetricsDiskWriteOpsPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsDiskReadBytesPerSecondMaximum                            ExportableInstanceField = "UtilizationMetricsDiskReadBytesPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsDiskWriteBytesPerSecondMaximum                           ExportableInstanceField = "UtilizationMetricsDiskWriteBytesPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsNetworkInBytesPerSecondMaximum                           ExportableInstanceField = "UtilizationMetricsNetworkInBytesPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsNetworkOutBytesPerSecondMaximum                          ExportableInstanceField = "UtilizationMetricsNetworkOutBytesPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsNetworkPacketsInPerSecondMaximum                         ExportableInstanceField = "UtilizationMetricsNetworkPacketsInPerSecondMaximum"
	ExportableInstanceFieldUtilizationMetricsNetworkPacketsOutPerSecondMaximum                        ExportableInstanceField = "UtilizationMetricsNetworkPacketsOutPerSecondMaximum"
	ExportableInstanceFieldCurrentOnDemandPrice                                                       ExportableInstanceField = "CurrentOnDemandPrice"
	ExportableInstanceFieldCurrentStandardOneYearNoUpfrontReservedPrice                               ExportableInstanceField = "CurrentStandardOneYearNoUpfrontReservedPrice"
	ExportableInstanceFieldCurrentStandardThreeYearNoUpfrontReservedPrice                             ExportableInstanceField = "CurrentStandardThreeYearNoUpfrontReservedPrice"
	ExportableInstanceFieldCurrentVcpus                                                               ExportableInstanceField = "CurrentVCpus"
	ExportableInstanceFieldCurrentMemory                                                              ExportableInstanceField = "CurrentMemory"
	ExportableInstanceFieldCurrentStorage                                                             ExportableInstanceField = "CurrentStorage"
	ExportableInstanceFieldCurrentNetwork                                                             ExportableInstanceField = "CurrentNetwork"
	ExportableInstanceFieldRecommendationOptionsInstanceType                                          ExportableInstanceField = "RecommendationOptionsInstanceType"
	ExportableInstanceFieldRecommendationOptionsProjectedUtilizationMetricsCpuMaximum                 ExportableInstanceField = "RecommendationOptionsProjectedUtilizationMetricsCpuMaximum"
	ExportableInstanceFieldRecommendationOptionsProjectedUtilizationMetricsMemoryMaximum              ExportableInstanceField = "RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum"
	ExportableInstanceFieldRecommendationOptionsPlatformDifferences                                   ExportableInstanceField = "RecommendationOptionsPlatformDifferences"
	ExportableInstanceFieldRecommendationOptionsPerformanceRisk                                       ExportableInstanceField = "RecommendationOptionsPerformanceRisk"
	ExportableInstanceFieldRecommendationOptionsVcpus                                                 ExportableInstanceField = "RecommendationOptionsVcpus"
	ExportableInstanceFieldRecommendationOptionsMemory                                                ExportableInstanceField = "RecommendationOptionsMemory"
	ExportableInstanceFieldRecommendationOptionsStorage                                               ExportableInstanceField = "RecommendationOptionsStorage"
	ExportableInstanceFieldRecommendationOptionsNetwork                                               ExportableInstanceField = "RecommendationOptionsNetwork"
	ExportableInstanceFieldRecommendationOptionsOnDemandPrice                                         ExportableInstanceField = "RecommendationOptionsOnDemandPrice"
	ExportableInstanceFieldRecommendationOptionsStandardOneYearNoUpfrontReservedPrice                 ExportableInstanceField = "RecommendationOptionsStandardOneYearNoUpfrontReservedPrice"
	ExportableInstanceFieldRecommendationOptionsStandardThreeYearNoUpfrontReservedPrice               ExportableInstanceField = "RecommendationOptionsStandardThreeYearNoUpfrontReservedPrice"
	ExportableInstanceFieldRecommendationsSourcesRecommendationSourceArn                              ExportableInstanceField = "RecommendationsSourcesRecommendationSourceArn"
	ExportableInstanceFieldRecommendationsSourcesRecommendationSourceType                             ExportableInstanceField = "RecommendationsSourcesRecommendationSourceType"
	ExportableInstanceFieldLastRefreshTimestamp                                                       ExportableInstanceField = "LastRefreshTimestamp"
	ExportableInstanceFieldCurrentPerformanceRisk                                                     ExportableInstanceField = "CurrentPerformanceRisk"
	ExportableInstanceFieldRecommendationOptionsSavingsOpportunityPercentage                          ExportableInstanceField = "RecommendationOptionsSavingsOpportunityPercentage"
	ExportableInstanceFieldRecommendationOptionsEstimatedMonthlySavingsCurrency                       ExportableInstanceField = "RecommendationOptionsEstimatedMonthlySavingsCurrency"
	ExportableInstanceFieldRecommendationOptionsEstimatedMonthlySavingsValue                          ExportableInstanceField = "RecommendationOptionsEstimatedMonthlySavingsValue"
	ExportableInstanceFieldEffectiveRecommendationPreferencesCpuVendorArchitectures                   ExportableInstanceField = "EffectiveRecommendationPreferencesCpuVendorArchitectures"
	ExportableInstanceFieldEffectiveRecommendationPreferencesEnhancedInfrastructureMetrics            ExportableInstanceField = "EffectiveRecommendationPreferencesEnhancedInfrastructureMetrics"
	ExportableInstanceFieldEffectiveRecommendationPreferencesInferredWorkloadTypes                    ExportableInstanceField = "EffectiveRecommendationPreferencesInferredWorkloadTypes"
	ExportableInstanceFieldInferredWorkloadTypes                                                      ExportableInstanceField = "InferredWorkloadTypes"
	ExportableInstanceFieldRecommendationOptionsMigrationEffort                                       ExportableInstanceField = "RecommendationOptionsMigrationEffort"
	ExportableInstanceFieldEffectiveRecommendationPreferencesExternalMetricsSource                    ExportableInstanceField = "EffectiveRecommendationPreferencesExternalMetricsSource"
	ExportableInstanceFieldTags                                                                       ExportableInstanceField = "Tags"
	ExportableInstanceFieldInstanceState                                                              ExportableInstanceField = "InstanceState"
	ExportableInstanceFieldExternalMetricStatusCode                                                   ExportableInstanceField = "ExternalMetricStatusCode"
	ExportableInstanceFieldExternalMetricStatusReason                                                 ExportableInstanceField = "ExternalMetricStatusReason"
	ExportableInstanceFieldCurrentInstanceGpuInfo                                                     ExportableInstanceField = "CurrentInstanceGpuInfo"
	ExportableInstanceFieldRecommendationOptionsInstanceGpuInfo                                       ExportableInstanceField = "RecommendationOptionsInstanceGpuInfo"
	ExportableInstanceFieldUtilizationMetricsGpuPercentageMaximum                                     ExportableInstanceField = "UtilizationMetricsGpuPercentageMaximum"
	ExportableInstanceFieldUtilizationMetricsGpuMemoryPercentageMaximum                               ExportableInstanceField = "UtilizationMetricsGpuMemoryPercentageMaximum"
	ExportableInstanceFieldRecommendationOptionsProjectedUtilizationMetricsGpuPercentageMaximum       ExportableInstanceField = "RecommendationOptionsProjectedUtilizationMetricsGpuPercentageMaximum"
	ExportableInstanceFieldRecommendationOptionsProjectedUtilizationMetricsGpuMemoryPercentageMaximum ExportableInstanceField = "RecommendationOptionsProjectedUtilizationMetricsGpuMemoryPercentageMaximum"
	ExportableInstanceFieldIdle                                                                       ExportableInstanceField = "Idle"
	ExportableInstanceFieldEffectiveRecommendationPreferencesPreferredResources                       ExportableInstanceField = "EffectiveRecommendationPreferencesPreferredResources"
	ExportableInstanceFieldEffectiveRecommendationPreferencesLookbackPeriod                           ExportableInstanceField = "EffectiveRecommendationPreferencesLookBackPeriod"
	ExportableInstanceFieldEffectiveRecommendationPreferencesUtilizationPreferences                   ExportableInstanceField = "EffectiveRecommendationPreferencesUtilizationPreferences"
	ExportableInstanceFieldEffectiveRecommendationPreferencesSavingsEstimationMode                    ExportableInstanceField = "EffectiveRecommendationPreferencesSavingsEstimationMode"
	ExportableInstanceFieldRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage            ExportableInstanceField = "RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage"
	ExportableInstanceFieldRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts         ExportableInstanceField = "RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts"
	ExportableInstanceFieldRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts            ExportableInstanceField = "RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts"
)

// Values returns all known values for ExportableInstanceField. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExportableInstanceField) Values() []ExportableInstanceField {
	return []ExportableInstanceField{
		"AccountId",
		"InstanceArn",
		"InstanceName",
		"Finding",
		"FindingReasonCodes",
		"LookbackPeriodInDays",
		"CurrentInstanceType",
		"UtilizationMetricsCpuMaximum",
		"UtilizationMetricsMemoryMaximum",
		"UtilizationMetricsEbsReadOpsPerSecondMaximum",
		"UtilizationMetricsEbsWriteOpsPerSecondMaximum",
		"UtilizationMetricsEbsReadBytesPerSecondMaximum",
		"UtilizationMetricsEbsWriteBytesPerSecondMaximum",
		"UtilizationMetricsDiskReadOpsPerSecondMaximum",
		"UtilizationMetricsDiskWriteOpsPerSecondMaximum",
		"UtilizationMetricsDiskReadBytesPerSecondMaximum",
		"UtilizationMetricsDiskWriteBytesPerSecondMaximum",
		"UtilizationMetricsNetworkInBytesPerSecondMaximum",
		"UtilizationMetricsNetworkOutBytesPerSecondMaximum",
		"UtilizationMetricsNetworkPacketsInPerSecondMaximum",
		"UtilizationMetricsNetworkPacketsOutPerSecondMaximum",
		"CurrentOnDemandPrice",
		"CurrentStandardOneYearNoUpfrontReservedPrice",
		"CurrentStandardThreeYearNoUpfrontReservedPrice",
		"CurrentVCpus",
		"CurrentMemory",
		"CurrentStorage",
		"CurrentNetwork",
		"RecommendationOptionsInstanceType",
		"RecommendationOptionsProjectedUtilizationMetricsCpuMaximum",
		"RecommendationOptionsProjectedUtilizationMetricsMemoryMaximum",
		"RecommendationOptionsPlatformDifferences",
		"RecommendationOptionsPerformanceRisk",
		"RecommendationOptionsVcpus",
		"RecommendationOptionsMemory",
		"RecommendationOptionsStorage",
		"RecommendationOptionsNetwork",
		"RecommendationOptionsOnDemandPrice",
		"RecommendationOptionsStandardOneYearNoUpfrontReservedPrice",
		"RecommendationOptionsStandardThreeYearNoUpfrontReservedPrice",
		"RecommendationsSourcesRecommendationSourceArn",
		"RecommendationsSourcesRecommendationSourceType",
		"LastRefreshTimestamp",
		"CurrentPerformanceRisk",
		"RecommendationOptionsSavingsOpportunityPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrency",
		"RecommendationOptionsEstimatedMonthlySavingsValue",
		"EffectiveRecommendationPreferencesCpuVendorArchitectures",
		"EffectiveRecommendationPreferencesEnhancedInfrastructureMetrics",
		"EffectiveRecommendationPreferencesInferredWorkloadTypes",
		"InferredWorkloadTypes",
		"RecommendationOptionsMigrationEffort",
		"EffectiveRecommendationPreferencesExternalMetricsSource",
		"Tags",
		"InstanceState",
		"ExternalMetricStatusCode",
		"ExternalMetricStatusReason",
		"CurrentInstanceGpuInfo",
		"RecommendationOptionsInstanceGpuInfo",
		"UtilizationMetricsGpuPercentageMaximum",
		"UtilizationMetricsGpuMemoryPercentageMaximum",
		"RecommendationOptionsProjectedUtilizationMetricsGpuPercentageMaximum",
		"RecommendationOptionsProjectedUtilizationMetricsGpuMemoryPercentageMaximum",
		"Idle",
		"EffectiveRecommendationPreferencesPreferredResources",
		"EffectiveRecommendationPreferencesLookBackPeriod",
		"EffectiveRecommendationPreferencesUtilizationPreferences",
		"EffectiveRecommendationPreferencesSavingsEstimationMode",
		"RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts",
		"RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts",
	}
}

type ExportableLambdaFunctionField string

// Enum values for ExportableLambdaFunctionField
const (
	ExportableLambdaFunctionFieldAccountId                                                          ExportableLambdaFunctionField = "AccountId"
	ExportableLambdaFunctionFieldFunctionArn                                                        ExportableLambdaFunctionField = "FunctionArn"
	ExportableLambdaFunctionFieldFunctionVersion                                                    ExportableLambdaFunctionField = "FunctionVersion"
	ExportableLambdaFunctionFieldFinding                                                            ExportableLambdaFunctionField = "Finding"
	ExportableLambdaFunctionFieldFindingReasonCodes                                                 ExportableLambdaFunctionField = "FindingReasonCodes"
	ExportableLambdaFunctionFieldNumberOfInvocations                                                ExportableLambdaFunctionField = "NumberOfInvocations"
	ExportableLambdaFunctionFieldUtilizationMetricsDurationMaximum                                  ExportableLambdaFunctionField = "UtilizationMetricsDurationMaximum"
	ExportableLambdaFunctionFieldUtilizationMetricsDurationAverage                                  ExportableLambdaFunctionField = "UtilizationMetricsDurationAverage"
	ExportableLambdaFunctionFieldUtilizationMetricsMemoryMaximum                                    ExportableLambdaFunctionField = "UtilizationMetricsMemoryMaximum"
	ExportableLambdaFunctionFieldUtilizationMetricsMemoryAverage                                    ExportableLambdaFunctionField = "UtilizationMetricsMemoryAverage"
	ExportableLambdaFunctionFieldLookbackPeriodInDays                                               ExportableLambdaFunctionField = "LookbackPeriodInDays"
	ExportableLambdaFunctionFieldCurrentConfigurationMemorySize                                     ExportableLambdaFunctionField = "CurrentConfigurationMemorySize"
	ExportableLambdaFunctionFieldCurrentConfigurationTimeout                                        ExportableLambdaFunctionField = "CurrentConfigurationTimeout"
	ExportableLambdaFunctionFieldCurrentCostTotal                                                   ExportableLambdaFunctionField = "CurrentCostTotal"
	ExportableLambdaFunctionFieldCurrentCostAverage                                                 ExportableLambdaFunctionField = "CurrentCostAverage"
	ExportableLambdaFunctionFieldRecommendationOptionsConfigurationMemorySize                       ExportableLambdaFunctionField = "RecommendationOptionsConfigurationMemorySize"
	ExportableLambdaFunctionFieldRecommendationOptionsCostLow                                       ExportableLambdaFunctionField = "RecommendationOptionsCostLow"
	ExportableLambdaFunctionFieldRecommendationOptionsCostHigh                                      ExportableLambdaFunctionField = "RecommendationOptionsCostHigh"
	ExportableLambdaFunctionFieldRecommendationOptionsProjectedUtilizationMetricsDurationLowerBound ExportableLambdaFunctionField = "RecommendationOptionsProjectedUtilizationMetricsDurationLowerBound"
	ExportableLambdaFunctionFieldRecommendationOptionsProjectedUtilizationMetricsDurationUpperBound ExportableLambdaFunctionField = "RecommendationOptionsProjectedUtilizationMetricsDurationUpperBound"
	ExportableLambdaFunctionFieldRecommendationOptionsProjectedUtilizationMetricsDurationExpected   ExportableLambdaFunctionField = "RecommendationOptionsProjectedUtilizationMetricsDurationExpected"
	ExportableLambdaFunctionFieldLastRefreshTimestamp                                               ExportableLambdaFunctionField = "LastRefreshTimestamp"
	ExportableLambdaFunctionFieldCurrentPerformanceRisk                                             ExportableLambdaFunctionField = "CurrentPerformanceRisk"
	ExportableLambdaFunctionFieldRecommendationOptionsSavingsOpportunityPercentage                  ExportableLambdaFunctionField = "RecommendationOptionsSavingsOpportunityPercentage"
	ExportableLambdaFunctionFieldRecommendationOptionsEstimatedMonthlySavingsCurrency               ExportableLambdaFunctionField = "RecommendationOptionsEstimatedMonthlySavingsCurrency"
	ExportableLambdaFunctionFieldRecommendationOptionsEstimatedMonthlySavingsValue                  ExportableLambdaFunctionField = "RecommendationOptionsEstimatedMonthlySavingsValue"
	ExportableLambdaFunctionFieldTags                                                               ExportableLambdaFunctionField = "Tags"
	ExportableLambdaFunctionFieldEffectiveRecommendationPreferencesSavingsEstimationMode            ExportableLambdaFunctionField = "EffectiveRecommendationPreferencesSavingsEstimationMode"
	ExportableLambdaFunctionFieldRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage    ExportableLambdaFunctionField = "RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage"
	ExportableLambdaFunctionFieldRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts ExportableLambdaFunctionField = "RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts"
	ExportableLambdaFunctionFieldRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts    ExportableLambdaFunctionField = "RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts"
)

// Values returns all known values for ExportableLambdaFunctionField. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExportableLambdaFunctionField) Values() []ExportableLambdaFunctionField {
	return []ExportableLambdaFunctionField{
		"AccountId",
		"FunctionArn",
		"FunctionVersion",
		"Finding",
		"FindingReasonCodes",
		"NumberOfInvocations",
		"UtilizationMetricsDurationMaximum",
		"UtilizationMetricsDurationAverage",
		"UtilizationMetricsMemoryMaximum",
		"UtilizationMetricsMemoryAverage",
		"LookbackPeriodInDays",
		"CurrentConfigurationMemorySize",
		"CurrentConfigurationTimeout",
		"CurrentCostTotal",
		"CurrentCostAverage",
		"RecommendationOptionsConfigurationMemorySize",
		"RecommendationOptionsCostLow",
		"RecommendationOptionsCostHigh",
		"RecommendationOptionsProjectedUtilizationMetricsDurationLowerBound",
		"RecommendationOptionsProjectedUtilizationMetricsDurationUpperBound",
		"RecommendationOptionsProjectedUtilizationMetricsDurationExpected",
		"LastRefreshTimestamp",
		"CurrentPerformanceRisk",
		"RecommendationOptionsSavingsOpportunityPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrency",
		"RecommendationOptionsEstimatedMonthlySavingsValue",
		"Tags",
		"EffectiveRecommendationPreferencesSavingsEstimationMode",
		"RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts",
		"RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts",
	}
}

type ExportableLicenseField string

// Enum values for ExportableLicenseField
const (
	ExportableLicenseFieldAccountId                                            ExportableLicenseField = "AccountId"
	ExportableLicenseFieldResourceArn                                          ExportableLicenseField = "ResourceArn"
	ExportableLicenseFieldLookbackPeriodInDays                                 ExportableLicenseField = "LookbackPeriodInDays"
	ExportableLicenseFieldLastRefreshTimestamp                                 ExportableLicenseField = "LastRefreshTimestamp"
	ExportableLicenseFieldLicenseFinding                                       ExportableLicenseField = "Finding"
	ExportableLicenseFieldLicenseFindingReasonCodes                            ExportableLicenseField = "FindingReasonCodes"
	ExportableLicenseFieldCurrentLicenseConfigurationNumberOfCores             ExportableLicenseField = "CurrentLicenseConfigurationNumberOfCores"
	ExportableLicenseFieldCurrentLicenseConfigurationInstanceType              ExportableLicenseField = "CurrentLicenseConfigurationInstanceType"
	ExportableLicenseFieldCurrentLicenseConfigurationOperatingSystem           ExportableLicenseField = "CurrentLicenseConfigurationOperatingSystem"
	ExportableLicenseFieldCurrentLicenseConfigurationLicenseName               ExportableLicenseField = "CurrentLicenseConfigurationLicenseName"
	ExportableLicenseFieldCurrentLicenseConfigurationLicenseEdition            ExportableLicenseField = "CurrentLicenseConfigurationLicenseEdition"
	ExportableLicenseFieldCurrentLicenseConfigurationLicenseModel              ExportableLicenseField = "CurrentLicenseConfigurationLicenseModel"
	ExportableLicenseFieldCurrentLicenseConfigurationLicenseVersion            ExportableLicenseField = "CurrentLicenseConfigurationLicenseVersion"
	ExportableLicenseFieldCurrentLicenseConfigurationMetricsSource             ExportableLicenseField = "CurrentLicenseConfigurationMetricsSource"
	ExportableLicenseFieldRecommendationOptionsOperatingSystem                 ExportableLicenseField = "RecommendationOptionsOperatingSystem"
	ExportableLicenseFieldRecommendationOptionsLicenseEdition                  ExportableLicenseField = "RecommendationOptionsLicenseEdition"
	ExportableLicenseFieldRecommendationOptionsLicenseModel                    ExportableLicenseField = "RecommendationOptionsLicenseModel"
	ExportableLicenseFieldRecommendationOptionsSavingsOpportunityPercentage    ExportableLicenseField = "RecommendationOptionsSavingsOpportunityPercentage"
	ExportableLicenseFieldRecommendationOptionsEstimatedMonthlySavingsCurrency ExportableLicenseField = "RecommendationOptionsEstimatedMonthlySavingsCurrency"
	ExportableLicenseFieldRecommendationOptionsEstimatedMonthlySavingsValue    ExportableLicenseField = "RecommendationOptionsEstimatedMonthlySavingsValue"
	ExportableLicenseFieldTags                                                 ExportableLicenseField = "Tags"
)

// Values returns all known values for ExportableLicenseField. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExportableLicenseField) Values() []ExportableLicenseField {
	return []ExportableLicenseField{
		"AccountId",
		"ResourceArn",
		"LookbackPeriodInDays",
		"LastRefreshTimestamp",
		"Finding",
		"FindingReasonCodes",
		"CurrentLicenseConfigurationNumberOfCores",
		"CurrentLicenseConfigurationInstanceType",
		"CurrentLicenseConfigurationOperatingSystem",
		"CurrentLicenseConfigurationLicenseName",
		"CurrentLicenseConfigurationLicenseEdition",
		"CurrentLicenseConfigurationLicenseModel",
		"CurrentLicenseConfigurationLicenseVersion",
		"CurrentLicenseConfigurationMetricsSource",
		"RecommendationOptionsOperatingSystem",
		"RecommendationOptionsLicenseEdition",
		"RecommendationOptionsLicenseModel",
		"RecommendationOptionsSavingsOpportunityPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrency",
		"RecommendationOptionsEstimatedMonthlySavingsValue",
		"Tags",
	}
}

type ExportableRDSDBField string

// Enum values for ExportableRDSDBField
const (
	ExportableRDSDBFieldResourceArn                                                                ExportableRDSDBField = "ResourceArn"
	ExportableRDSDBFieldAccountId                                                                  ExportableRDSDBField = "AccountId"
	ExportableRDSDBFieldEngine                                                                     ExportableRDSDBField = "Engine"
	ExportableRDSDBFieldEngineVersion                                                              ExportableRDSDBField = "EngineVersion"
	ExportableRDSDBFieldIdle                                                                       ExportableRDSDBField = "Idle"
	ExportableRDSDBFieldMultiAzDbInstance                                                          ExportableRDSDBField = "MultiAZDBInstance"
	ExportableRDSDBFieldClusterWriter                                                              ExportableRDSDBField = "ClusterWriter"
	ExportableRDSDBFieldCurrentDbInstanceClass                                                     ExportableRDSDBField = "CurrentDBInstanceClass"
	ExportableRDSDBFieldCurrentStorageConfigurationStorageType                                     ExportableRDSDBField = "CurrentStorageConfigurationStorageType"
	ExportableRDSDBFieldCurrentStorageConfigurationAllocatedStorage                                ExportableRDSDBField = "CurrentStorageConfigurationAllocatedStorage"
	ExportableRDSDBFieldCurrentStorageConfigurationMaxAllocatedStorage                             ExportableRDSDBField = "CurrentStorageConfigurationMaxAllocatedStorage"
	ExportableRDSDBFieldCurrentStorageConfigurationIops                                            ExportableRDSDBField = "CurrentStorageConfigurationIOPS"
	ExportableRDSDBFieldCurrentStorageConfigurationStorageThroughput                               ExportableRDSDBField = "CurrentStorageConfigurationStorageThroughput"
	ExportableRDSDBFieldCurrentStorageEstimatedMonthlyVolumeIopsCostVariation                      ExportableRDSDBField = "CurrentStorageEstimatedMonthlyVolumeIOPsCostVariation"
	ExportableRDSDBFieldCurrentInstanceOnDemandHourlyPrice                                         ExportableRDSDBField = "CurrentInstanceOnDemandHourlyPrice"
	ExportableRDSDBFieldCurrentStorageOnDemandMonthlyPrice                                         ExportableRDSDBField = "CurrentStorageOnDemandMonthlyPrice"
	ExportableRDSDBFieldLookbackPeriodInDays                                                       ExportableRDSDBField = "LookbackPeriodInDays"
	ExportableRDSDBFieldCurrentStorageEstimatedClusterInstanceOnDemandMonthlyCost                  ExportableRDSDBField = "CurrentStorageEstimatedClusterInstanceOnDemandMonthlyCost"
	ExportableRDSDBFieldCurrentStorageEstimatedClusterStorageOnDemandMonthlyCost                   ExportableRDSDBField = "CurrentStorageEstimatedClusterStorageOnDemandMonthlyCost"
	ExportableRDSDBFieldCurrentStorageEstimatedClusterStorageIoOnDemandMonthlyCost                 ExportableRDSDBField = "CurrentStorageEstimatedClusterStorageIOOnDemandMonthlyCost"
	ExportableRDSDBFieldCurrentInstancePerformanceRisk                                             ExportableRDSDBField = "CurrentInstancePerformanceRisk"
	ExportableRDSDBFieldUtilizationMetricsCpuMaximum                                               ExportableRDSDBField = "UtilizationMetricsCpuMaximum"
	ExportableRDSDBFieldUtilizationMetricsMemoryMaximum                                            ExportableRDSDBField = "UtilizationMetricsMemoryMaximum"
	ExportableRDSDBFieldUtilizationMetricsEbsVolumeStorageSpaceUtilizationMaximum                  ExportableRDSDBField = "UtilizationMetricsEBSVolumeStorageSpaceUtilizationMaximum"
	ExportableRDSDBFieldUtilizationMetricsNetworkReceiveThroughputMaximum                          ExportableRDSDBField = "UtilizationMetricsNetworkReceiveThroughputMaximum"
	ExportableRDSDBFieldUtilizationMetricsNetworkTransmitThroughputMaximum                         ExportableRDSDBField = "UtilizationMetricsNetworkTransmitThroughputMaximum"
	ExportableRDSDBFieldUtilizationMetricsEbsVolumeReadIopsMaximum                                 ExportableRDSDBField = "UtilizationMetricsEBSVolumeReadIOPSMaximum"
	ExportableRDSDBFieldUtilizationMetricsEbsVolumeWriteIopsMaximum                                ExportableRDSDBField = "UtilizationMetricsEBSVolumeWriteIOPSMaximum"
	ExportableRDSDBFieldUtilizationMetricsEbsVolumeReadThroughputMaximum                           ExportableRDSDBField = "UtilizationMetricsEBSVolumeReadThroughputMaximum"
	ExportableRDSDBFieldUtilizationMetricsEbsVolumeWriteThroughputMaximum                          ExportableRDSDBField = "UtilizationMetricsEBSVolumeWriteThroughputMaximum"
	ExportableRDSDBFieldUtilizationMetricsDatabaseConnectionsMaximum                               ExportableRDSDBField = "UtilizationMetricsDatabaseConnectionsMaximum"
	ExportableRDSDBFieldUtilizationMetricsStorageNetworkReceiveThroughputMaximum                   ExportableRDSDBField = "UtilizationMetricsStorageNetworkReceiveThroughputMaximum"
	ExportableRDSDBFieldUtilizationMetricsStorageNetworkTransmitThroughputMaximum                  ExportableRDSDBField = "UtilizationMetricsStorageNetworkTransmitThroughputMaximum"
	ExportableRDSDBFieldUtilizationMetricsAuroraMemoryHealthStateMaximum                           ExportableRDSDBField = "UtilizationMetricsAuroraMemoryHealthStateMaximum"
	ExportableRDSDBFieldUtilizationMetricsAuroraMemoryNumDeclinedSqlTotalMaximum                   ExportableRDSDBField = "UtilizationMetricsAuroraMemoryNumDeclinedSqlTotalMaximum"
	ExportableRDSDBFieldUtilizationMetricsAuroraMemoryNumKillConnTotalMaximum                      ExportableRDSDBField = "UtilizationMetricsAuroraMemoryNumKillConnTotalMaximum"
	ExportableRDSDBFieldUtilizationMetricsAuroraMemoryNumKillQueryTotalMaximum                     ExportableRDSDBField = "UtilizationMetricsAuroraMemoryNumKillQueryTotalMaximum"
	ExportableRDSDBFieldUtilizationMetricsReadIopsEphemeralStorageMaximum                          ExportableRDSDBField = "UtilizationMetricsReadIOPSEphemeralStorageMaximum"
	ExportableRDSDBFieldUtilizationMetricsWriteIopsEphemeralStorageMaximum                         ExportableRDSDBField = "UtilizationMetricsWriteIOPSEphemeralStorageMaximum"
	ExportableRDSDBFieldUtilizationMetricsVolumeBytesUsedAverage                                   ExportableRDSDBField = "UtilizationMetricsVolumeBytesUsedAverage"
	ExportableRDSDBFieldUtilizationMetricsVolumeReadIopsAverage                                    ExportableRDSDBField = "UtilizationMetricsVolumeReadIOPsAverage"
	ExportableRDSDBFieldUtilizationMetricsVolumeWriteIopsAverage                                   ExportableRDSDBField = "UtilizationMetricsVolumeWriteIOPsAverage"
	ExportableRDSDBFieldInstanceFinding                                                            ExportableRDSDBField = "InstanceFinding"
	ExportableRDSDBFieldInstanceFindingReasonCodes                                                 ExportableRDSDBField = "InstanceFindingReasonCodes"
	ExportableRDSDBFieldStorageFinding                                                             ExportableRDSDBField = "StorageFinding"
	ExportableRDSDBFieldStorageFindingReasonCodes                                                  ExportableRDSDBField = "StorageFindingReasonCodes"
	ExportableRDSDBFieldInstanceRecommendationOptionsDbInstanceClass                               ExportableRDSDBField = "InstanceRecommendationOptionsDBInstanceClass"
	ExportableRDSDBFieldInstanceRecommendationOptionsRank                                          ExportableRDSDBField = "InstanceRecommendationOptionsRank"
	ExportableRDSDBFieldInstanceRecommendationOptionsPerformanceRisk                               ExportableRDSDBField = "InstanceRecommendationOptionsPerformanceRisk"
	ExportableRDSDBFieldInstanceRecommendationOptionsProjectedUtilizationMetricsCpuMaximum         ExportableRDSDBField = "InstanceRecommendationOptionsProjectedUtilizationMetricsCpuMaximum"
	ExportableRDSDBFieldStorageRecommendationOptionsStorageType                                    ExportableRDSDBField = "StorageRecommendationOptionsStorageType"
	ExportableRDSDBFieldStorageRecommendationOptionsAllocatedStorage                               ExportableRDSDBField = "StorageRecommendationOptionsAllocatedStorage"
	ExportableRDSDBFieldStorageRecommendationOptionsMaxAllocatedStorage                            ExportableRDSDBField = "StorageRecommendationOptionsMaxAllocatedStorage"
	ExportableRDSDBFieldStorageRecommendationOptionsIops                                           ExportableRDSDBField = "StorageRecommendationOptionsIOPS"
	ExportableRDSDBFieldStorageRecommendationOptionsStorageThroughput                              ExportableRDSDBField = "StorageRecommendationOptionsStorageThroughput"
	ExportableRDSDBFieldStorageRecommendationOptionsRank                                           ExportableRDSDBField = "StorageRecommendationOptionsRank"
	ExportableRDSDBFieldStorageRecommendationOptionsEstimatedMonthlyVolumeIopsCostVariation        ExportableRDSDBField = "StorageRecommendationOptionsEstimatedMonthlyVolumeIOPsCostVariation"
	ExportableRDSDBFieldInstanceRecommendationOptionsInstanceOnDemandHourlyPrice                   ExportableRDSDBField = "InstanceRecommendationOptionsInstanceOnDemandHourlyPrice"
	ExportableRDSDBFieldInstanceRecommendationOptionsSavingsOpportunityPercentage                  ExportableRDSDBField = "InstanceRecommendationOptionsSavingsOpportunityPercentage"
	ExportableRDSDBFieldInstanceRecommendationOptionsEstimatedMonthlySavingsCurrency               ExportableRDSDBField = "InstanceRecommendationOptionsEstimatedMonthlySavingsCurrency"
	ExportableRDSDBFieldInstanceRecommendationOptionsEstimatedMonthlySavingsValue                  ExportableRDSDBField = "InstanceRecommendationOptionsEstimatedMonthlySavingsValue"
	ExportableRDSDBFieldInstanceRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage    ExportableRDSDBField = "InstanceRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage"
	ExportableRDSDBFieldInstanceRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts ExportableRDSDBField = "InstanceRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts"
	ExportableRDSDBFieldInstanceRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts    ExportableRDSDBField = "InstanceRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts"
	ExportableRDSDBFieldStorageRecommendationOptionsOnDemandMonthlyPrice                           ExportableRDSDBField = "StorageRecommendationOptionsOnDemandMonthlyPrice"
	ExportableRDSDBFieldStorageRecommendationOptionsEstimatedClusterInstanceOnDemandMonthlyCost    ExportableRDSDBField = "StorageRecommendationOptionsEstimatedClusterInstanceOnDemandMonthlyCost"
	ExportableRDSDBFieldStorageRecommendationOptionsEstimatedClusterStorageOnDemandMonthlyCost     ExportableRDSDBField = "StorageRecommendationOptionsEstimatedClusterStorageOnDemandMonthlyCost"
	ExportableRDSDBFieldStorageRecommendationOptionsEstimatedClusterStorageIoOnDemandMonthlyCost   ExportableRDSDBField = "StorageRecommendationOptionsEstimatedClusterStorageIOOnDemandMonthlyCost"
	ExportableRDSDBFieldStorageRecommendationOptionsSavingsOpportunityPercentage                   ExportableRDSDBField = "StorageRecommendationOptionsSavingsOpportunityPercentage"
	ExportableRDSDBFieldStorageRecommendationOptionsEstimatedMonthlySavingsCurrency                ExportableRDSDBField = "StorageRecommendationOptionsEstimatedMonthlySavingsCurrency"
	ExportableRDSDBFieldStorageRecommendationOptionsEstimatedMonthlySavingsValue                   ExportableRDSDBField = "StorageRecommendationOptionsEstimatedMonthlySavingsValue"
	ExportableRDSDBFieldStorageRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage     ExportableRDSDBField = "StorageRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage"
	ExportableRDSDBFieldStorageRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts  ExportableRDSDBField = "StorageRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts"
	ExportableRDSDBFieldStorageRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts     ExportableRDSDBField = "StorageRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts"
	ExportableRDSDBFieldEffectiveRecommendationPreferencesCpuVendorArchitectures                   ExportableRDSDBField = "EffectiveRecommendationPreferencesCpuVendorArchitectures"
	ExportableRDSDBFieldEffectiveRecommendationPreferencesEnhancedInfrastructureMetrics            ExportableRDSDBField = "EffectiveRecommendationPreferencesEnhancedInfrastructureMetrics"
	ExportableRDSDBFieldEffectiveRecommendationPreferencesLookbackPeriod                           ExportableRDSDBField = "EffectiveRecommendationPreferencesLookBackPeriod"
	ExportableRDSDBFieldEffectiveRecommendationPreferencesSavingsEstimationMode                    ExportableRDSDBField = "EffectiveRecommendationPreferencesSavingsEstimationMode"
	ExportableRDSDBFieldLastRefreshTimestamp                                                       ExportableRDSDBField = "LastRefreshTimestamp"
	ExportableRDSDBFieldTags                                                                       ExportableRDSDBField = "Tags"
	ExportableRDSDBFieldDbClusterIdentifier                                                        ExportableRDSDBField = "DBClusterIdentifier"
	ExportableRDSDBFieldPromotionTier                                                              ExportableRDSDBField = "PromotionTier"
)

// Values returns all known values for ExportableRDSDBField. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExportableRDSDBField) Values() []ExportableRDSDBField {
	return []ExportableRDSDBField{
		"ResourceArn",
		"AccountId",
		"Engine",
		"EngineVersion",
		"Idle",
		"MultiAZDBInstance",
		"ClusterWriter",
		"CurrentDBInstanceClass",
		"CurrentStorageConfigurationStorageType",
		"CurrentStorageConfigurationAllocatedStorage",
		"CurrentStorageConfigurationMaxAllocatedStorage",
		"CurrentStorageConfigurationIOPS",
		"CurrentStorageConfigurationStorageThroughput",
		"CurrentStorageEstimatedMonthlyVolumeIOPsCostVariation",
		"CurrentInstanceOnDemandHourlyPrice",
		"CurrentStorageOnDemandMonthlyPrice",
		"LookbackPeriodInDays",
		"CurrentStorageEstimatedClusterInstanceOnDemandMonthlyCost",
		"CurrentStorageEstimatedClusterStorageOnDemandMonthlyCost",
		"CurrentStorageEstimatedClusterStorageIOOnDemandMonthlyCost",
		"CurrentInstancePerformanceRisk",
		"UtilizationMetricsCpuMaximum",
		"UtilizationMetricsMemoryMaximum",
		"UtilizationMetricsEBSVolumeStorageSpaceUtilizationMaximum",
		"UtilizationMetricsNetworkReceiveThroughputMaximum",
		"UtilizationMetricsNetworkTransmitThroughputMaximum",
		"UtilizationMetricsEBSVolumeReadIOPSMaximum",
		"UtilizationMetricsEBSVolumeWriteIOPSMaximum",
		"UtilizationMetricsEBSVolumeReadThroughputMaximum",
		"UtilizationMetricsEBSVolumeWriteThroughputMaximum",
		"UtilizationMetricsDatabaseConnectionsMaximum",
		"UtilizationMetricsStorageNetworkReceiveThroughputMaximum",
		"UtilizationMetricsStorageNetworkTransmitThroughputMaximum",
		"UtilizationMetricsAuroraMemoryHealthStateMaximum",
		"UtilizationMetricsAuroraMemoryNumDeclinedSqlTotalMaximum",
		"UtilizationMetricsAuroraMemoryNumKillConnTotalMaximum",
		"UtilizationMetricsAuroraMemoryNumKillQueryTotalMaximum",
		"UtilizationMetricsReadIOPSEphemeralStorageMaximum",
		"UtilizationMetricsWriteIOPSEphemeralStorageMaximum",
		"UtilizationMetricsVolumeBytesUsedAverage",
		"UtilizationMetricsVolumeReadIOPsAverage",
		"UtilizationMetricsVolumeWriteIOPsAverage",
		"InstanceFinding",
		"InstanceFindingReasonCodes",
		"StorageFinding",
		"StorageFindingReasonCodes",
		"InstanceRecommendationOptionsDBInstanceClass",
		"InstanceRecommendationOptionsRank",
		"InstanceRecommendationOptionsPerformanceRisk",
		"InstanceRecommendationOptionsProjectedUtilizationMetricsCpuMaximum",
		"StorageRecommendationOptionsStorageType",
		"StorageRecommendationOptionsAllocatedStorage",
		"StorageRecommendationOptionsMaxAllocatedStorage",
		"StorageRecommendationOptionsIOPS",
		"StorageRecommendationOptionsStorageThroughput",
		"StorageRecommendationOptionsRank",
		"StorageRecommendationOptionsEstimatedMonthlyVolumeIOPsCostVariation",
		"InstanceRecommendationOptionsInstanceOnDemandHourlyPrice",
		"InstanceRecommendationOptionsSavingsOpportunityPercentage",
		"InstanceRecommendationOptionsEstimatedMonthlySavingsCurrency",
		"InstanceRecommendationOptionsEstimatedMonthlySavingsValue",
		"InstanceRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage",
		"InstanceRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts",
		"InstanceRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts",
		"StorageRecommendationOptionsOnDemandMonthlyPrice",
		"StorageRecommendationOptionsEstimatedClusterInstanceOnDemandMonthlyCost",
		"StorageRecommendationOptionsEstimatedClusterStorageOnDemandMonthlyCost",
		"StorageRecommendationOptionsEstimatedClusterStorageIOOnDemandMonthlyCost",
		"StorageRecommendationOptionsSavingsOpportunityPercentage",
		"StorageRecommendationOptionsEstimatedMonthlySavingsCurrency",
		"StorageRecommendationOptionsEstimatedMonthlySavingsValue",
		"StorageRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage",
		"StorageRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts",
		"StorageRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts",
		"EffectiveRecommendationPreferencesCpuVendorArchitectures",
		"EffectiveRecommendationPreferencesEnhancedInfrastructureMetrics",
		"EffectiveRecommendationPreferencesLookBackPeriod",
		"EffectiveRecommendationPreferencesSavingsEstimationMode",
		"LastRefreshTimestamp",
		"Tags",
		"DBClusterIdentifier",
		"PromotionTier",
	}
}

type ExportableVolumeField string

// Enum values for ExportableVolumeField
const (
	ExportableVolumeFieldAccountId                                                          ExportableVolumeField = "AccountId"
	ExportableVolumeFieldVolumeArn                                                          ExportableVolumeField = "VolumeArn"
	ExportableVolumeFieldFinding                                                            ExportableVolumeField = "Finding"
	ExportableVolumeFieldUtilizationMetricsVolumeReadOpsPerSecondMaximum                    ExportableVolumeField = "UtilizationMetricsVolumeReadOpsPerSecondMaximum"
	ExportableVolumeFieldUtilizationMetricsVolumeWriteOpsPerSecondMaximum                   ExportableVolumeField = "UtilizationMetricsVolumeWriteOpsPerSecondMaximum"
	ExportableVolumeFieldUtilizationMetricsVolumeReadBytesPerSecondMaximum                  ExportableVolumeField = "UtilizationMetricsVolumeReadBytesPerSecondMaximum"
	ExportableVolumeFieldUtilizationMetricsVolumeWriteBytesPerSecondMaximum                 ExportableVolumeField = "UtilizationMetricsVolumeWriteBytesPerSecondMaximum"
	ExportableVolumeFieldUtilizationMetricsVolumeIopsExceededMaximum                        ExportableVolumeField = "UtilizationMetricsVolumeIOPSExceededMaximum"
	ExportableVolumeFieldUtilizationMetricsVolumeThroughputExceededMaximum                  ExportableVolumeField = "UtilizationMetricsVolumeThroughputExceededMaximum"
	ExportableVolumeFieldLookbackPeriodInDays                                               ExportableVolumeField = "LookbackPeriodInDays"
	ExportableVolumeFieldCurrentConfigurationVolumeType                                     ExportableVolumeField = "CurrentConfigurationVolumeType"
	ExportableVolumeFieldCurrentConfigurationVolumeBaselineIops                             ExportableVolumeField = "CurrentConfigurationVolumeBaselineIOPS"
	ExportableVolumeFieldCurrentConfigurationVolumeBaselineThroughput                       ExportableVolumeField = "CurrentConfigurationVolumeBaselineThroughput"
	ExportableVolumeFieldCurrentConfigurationVolumeBurstIops                                ExportableVolumeField = "CurrentConfigurationVolumeBurstIOPS"
	ExportableVolumeFieldCurrentConfigurationVolumeBurstThroughput                          ExportableVolumeField = "CurrentConfigurationVolumeBurstThroughput"
	ExportableVolumeFieldCurrentConfigurationVolumeSize                                     ExportableVolumeField = "CurrentConfigurationVolumeSize"
	ExportableVolumeFieldCurrentMonthlyPrice                                                ExportableVolumeField = "CurrentMonthlyPrice"
	ExportableVolumeFieldRecommendationOptionsConfigurationVolumeType                       ExportableVolumeField = "RecommendationOptionsConfigurationVolumeType"
	ExportableVolumeFieldRecommendationOptionsConfigurationVolumeBaselineIops               ExportableVolumeField = "RecommendationOptionsConfigurationVolumeBaselineIOPS"
	ExportableVolumeFieldRecommendationOptionsConfigurationVolumeBaselineThroughput         ExportableVolumeField = "RecommendationOptionsConfigurationVolumeBaselineThroughput"
	ExportableVolumeFieldRecommendationOptionsConfigurationVolumeBurstIops                  ExportableVolumeField = "RecommendationOptionsConfigurationVolumeBurstIOPS"
	ExportableVolumeFieldRecommendationOptionsConfigurationVolumeBurstThroughput            ExportableVolumeField = "RecommendationOptionsConfigurationVolumeBurstThroughput"
	ExportableVolumeFieldRecommendationOptionsConfigurationVolumeSize                       ExportableVolumeField = "RecommendationOptionsConfigurationVolumeSize"
	ExportableVolumeFieldRecommendationOptionsMonthlyPrice                                  ExportableVolumeField = "RecommendationOptionsMonthlyPrice"
	ExportableVolumeFieldRecommendationOptionsPerformanceRisk                               ExportableVolumeField = "RecommendationOptionsPerformanceRisk"
	ExportableVolumeFieldLastRefreshTimestamp                                               ExportableVolumeField = "LastRefreshTimestamp"
	ExportableVolumeFieldCurrentPerformanceRisk                                             ExportableVolumeField = "CurrentPerformanceRisk"
	ExportableVolumeFieldRecommendationOptionsSavingsOpportunityPercentage                  ExportableVolumeField = "RecommendationOptionsSavingsOpportunityPercentage"
	ExportableVolumeFieldRecommendationOptionsEstimatedMonthlySavingsCurrency               ExportableVolumeField = "RecommendationOptionsEstimatedMonthlySavingsCurrency"
	ExportableVolumeFieldRecommendationOptionsEstimatedMonthlySavingsValue                  ExportableVolumeField = "RecommendationOptionsEstimatedMonthlySavingsValue"
	ExportableVolumeFieldTags                                                               ExportableVolumeField = "Tags"
	ExportableVolumeFieldRootVolume                                                         ExportableVolumeField = "RootVolume"
	ExportableVolumeFieldCurrentConfigurationRootVolume                                     ExportableVolumeField = "CurrentConfigurationRootVolume"
	ExportableVolumeFieldEffectiveRecommendationPreferencesSavingsEstimationMode            ExportableVolumeField = "EffectiveRecommendationPreferencesSavingsEstimationMode"
	ExportableVolumeFieldRecommendationOptionsSavingsOpportunityAfterDiscountsPercentage    ExportableVolumeField = "RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage"
	ExportableVolumeFieldRecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts ExportableVolumeField = "RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts"
	ExportableVolumeFieldRecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts    ExportableVolumeField = "RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts"
	ExportableVolumeFieldEffectiveRecommendationPreferencesLookbackPeriod                   ExportableVolumeField = "EffectiveRecommendationPreferencesLookBackPeriod"
)

// Values returns all known values for ExportableVolumeField. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExportableVolumeField) Values() []ExportableVolumeField {
	return []ExportableVolumeField{
		"AccountId",
		"VolumeArn",
		"Finding",
		"UtilizationMetricsVolumeReadOpsPerSecondMaximum",
		"UtilizationMetricsVolumeWriteOpsPerSecondMaximum",
		"UtilizationMetricsVolumeReadBytesPerSecondMaximum",
		"UtilizationMetricsVolumeWriteBytesPerSecondMaximum",
		"UtilizationMetricsVolumeIOPSExceededMaximum",
		"UtilizationMetricsVolumeThroughputExceededMaximum",
		"LookbackPeriodInDays",
		"CurrentConfigurationVolumeType",
		"CurrentConfigurationVolumeBaselineIOPS",
		"CurrentConfigurationVolumeBaselineThroughput",
		"CurrentConfigurationVolumeBurstIOPS",
		"CurrentConfigurationVolumeBurstThroughput",
		"CurrentConfigurationVolumeSize",
		"CurrentMonthlyPrice",
		"RecommendationOptionsConfigurationVolumeType",
		"RecommendationOptionsConfigurationVolumeBaselineIOPS",
		"RecommendationOptionsConfigurationVolumeBaselineThroughput",
		"RecommendationOptionsConfigurationVolumeBurstIOPS",
		"RecommendationOptionsConfigurationVolumeBurstThroughput",
		"RecommendationOptionsConfigurationVolumeSize",
		"RecommendationOptionsMonthlyPrice",
		"RecommendationOptionsPerformanceRisk",
		"LastRefreshTimestamp",
		"CurrentPerformanceRisk",
		"RecommendationOptionsSavingsOpportunityPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrency",
		"RecommendationOptionsEstimatedMonthlySavingsValue",
		"Tags",
		"RootVolume",
		"CurrentConfigurationRootVolume",
		"EffectiveRecommendationPreferencesSavingsEstimationMode",
		"RecommendationOptionsSavingsOpportunityAfterDiscountsPercentage",
		"RecommendationOptionsEstimatedMonthlySavingsCurrencyAfterDiscounts",
		"RecommendationOptionsEstimatedMonthlySavingsValueAfterDiscounts",
		"EffectiveRecommendationPreferencesLookBackPeriod",
	}
}

type ExternalMetricsSource string

// Enum values for ExternalMetricsSource
const (
	ExternalMetricsSourceDatadog   ExternalMetricsSource = "Datadog"
	ExternalMetricsSourceDynatrace ExternalMetricsSource = "Dynatrace"
	ExternalMetricsSourceNewrelic  ExternalMetricsSource = "NewRelic"
	ExternalMetricsSourceInstana   ExternalMetricsSource = "Instana"
)

// Values returns all known values for ExternalMetricsSource. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExternalMetricsSource) Values() []ExternalMetricsSource {
	return []ExternalMetricsSource{
		"Datadog",
		"Dynatrace",
		"NewRelic",
		"Instana",
	}
}

type ExternalMetricStatusCode string

// Enum values for ExternalMetricStatusCode
const (
	ExternalMetricStatusCodeNoExternalMetricSet          ExternalMetricStatusCode = "NO_EXTERNAL_METRIC_SET"
	ExternalMetricStatusCodeIntegrationSuccess           ExternalMetricStatusCode = "INTEGRATION_SUCCESS"
	ExternalMetricStatusCodeDatadogIntegrationError      ExternalMetricStatusCode = "DATADOG_INTEGRATION_ERROR"
	ExternalMetricStatusCodeDynatraceIntegrationError    ExternalMetricStatusCode = "DYNATRACE_INTEGRATION_ERROR"
	ExternalMetricStatusCodeNewrelicIntegrationError     ExternalMetricStatusCode = "NEWRELIC_INTEGRATION_ERROR"
	ExternalMetricStatusCodeInstanaIntegrationError      ExternalMetricStatusCode = "INSTANA_INTEGRATION_ERROR"
	ExternalMetricStatusCodeInsufficientDatadogMetrics   ExternalMetricStatusCode = "INSUFFICIENT_DATADOG_METRICS"
	ExternalMetricStatusCodeInsufficientDynatraceMetrics ExternalMetricStatusCode = "INSUFFICIENT_DYNATRACE_METRICS"
	ExternalMetricStatusCodeInsufficientNewrelicMetrics  ExternalMetricStatusCode = "INSUFFICIENT_NEWRELIC_METRICS"
	ExternalMetricStatusCodeInsufficientInstanaMetrics   ExternalMetricStatusCode = "INSUFFICIENT_INSTANA_METRICS"
)

// Values returns all known values for ExternalMetricStatusCode. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExternalMetricStatusCode) Values() []ExternalMetricStatusCode {
	return []ExternalMetricStatusCode{
		"NO_EXTERNAL_METRIC_SET",
		"INTEGRATION_SUCCESS",
		"DATADOG_INTEGRATION_ERROR",
		"DYNATRACE_INTEGRATION_ERROR",
		"NEWRELIC_INTEGRATION_ERROR",
		"INSTANA_INTEGRATION_ERROR",
		"INSUFFICIENT_DATADOG_METRICS",
		"INSUFFICIENT_DYNATRACE_METRICS",
		"INSUFFICIENT_NEWRELIC_METRICS",
		"INSUFFICIENT_INSTANA_METRICS",
	}
}

type FileFormat string

// Enum values for FileFormat
const (
	FileFormatCsv FileFormat = "Csv"
)

// Values returns all known values for FileFormat. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FileFormat) Values() []FileFormat {
	return []FileFormat{
		"Csv",
	}
}

type FilterName string

// Enum values for FilterName
const (
	FilterNameFinding                  FilterName = "Finding"
	FilterNameFindingReasonCodes       FilterName = "FindingReasonCodes"
	FilterNameRecommendationSourceType FilterName = "RecommendationSourceType"
	FilterNameInferredWorkloadTypes    FilterName = "InferredWorkloadTypes"
)

// Values returns all known values for FilterName. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FilterName) Values() []FilterName {
	return []FilterName{
		"Finding",
		"FindingReasonCodes",
		"RecommendationSourceType",
		"InferredWorkloadTypes",
	}
}

type Finding string

// Enum values for Finding
const (
	FindingUnderProvisioned Finding = "Underprovisioned"
	FindingOverProvisioned  Finding = "Overprovisioned"
	FindingOptimized        Finding = "Optimized"
	FindingNotOptimized     Finding = "NotOptimized"
)

// Values returns all known values for Finding. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Finding) Values() []Finding {
	return []Finding{
		"Underprovisioned",
		"Overprovisioned",
		"Optimized",
		"NotOptimized",
	}
}

type FindingReasonCode string

// Enum values for FindingReasonCode
const (
	FindingReasonCodeMemoryOverProvisioned  FindingReasonCode = "MemoryOverprovisioned"
	FindingReasonCodeMemoryUnderProvisioned FindingReasonCode = "MemoryUnderprovisioned"
)

// Values returns all known values for FindingReasonCode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FindingReasonCode) Values() []FindingReasonCode {
	return []FindingReasonCode{
		"MemoryOverprovisioned",
		"MemoryUnderprovisioned",
	}
}

type Idle string

// Enum values for Idle
const (
	IdleTrue  Idle = "True"
	IdleFalse Idle = "False"
)

// Values returns all known values for Idle. Note that this can be expanded in the
// future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Idle) Values() []Idle {
	return []Idle{
		"True",
		"False",
	}
}

type IdleFinding string

// Enum values for IdleFinding
const (
	IdleFindingIdle       IdleFinding = "Idle"
	IdleFindingUnattached IdleFinding = "Unattached"
	IdleFindingUnused     IdleFinding = "Unused"
)

// Values returns all known values for IdleFinding. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (IdleFinding) Values() []IdleFinding {
	return []IdleFinding{
		"Idle",
		"Unattached",
		"Unused",
	}
}

type IdleMetricName string

// Enum values for IdleMetricName
const (
	IdleMetricNameCpu                            IdleMetricName = "CPU"
	IdleMetricNameMemory                         IdleMetricName = "Memory"
	IdleMetricNameNetworkOutBytesPerSecond       IdleMetricName = "NetworkOutBytesPerSecond"
	IdleMetricNameNetworkInBytesPerSecond        IdleMetricName = "NetworkInBytesPerSecond"
	IdleMetricNameDatabaseConnections            IdleMetricName = "DatabaseConnections"
	IdleMetricNameEbsVolumeReadIops              IdleMetricName = "EBSVolumeReadIOPS"
	IdleMetricNameEbsVolumeWriteIops             IdleMetricName = "EBSVolumeWriteIOPS"
	IdleMetricNameVolumeReadOpsPerSecond         IdleMetricName = "VolumeReadOpsPerSecond"
	IdleMetricNameVolumeWriteOpsPerSecond        IdleMetricName = "VolumeWriteOpsPerSecond"
	IdleMetricNameActiveConnectionCount          IdleMetricName = "ActiveConnectionCount"
	IdleMetricNamePacketsInFromSource            IdleMetricName = "PacketsInFromSource"
	IdleMetricNamePacketsInFromDestination       IdleMetricName = "PacketsInFromDestination"
	IdleMetricNameConsumedReadCapacityUnits      IdleMetricName = "ConsumedReadCapacityUnits"
	IdleMetricNameConsumedWriteCapacityUnits     IdleMetricName = "ConsumedWriteCapacityUnits"
	IdleMetricNameConsumedChangeDataCaptureUnits IdleMetricName = "ConsumedChangeDataCaptureUnits"
	IdleMetricNameNewConnections                 IdleMetricName = "NewConnections"
	IdleMetricNameEngineCpuUtilization           IdleMetricName = "EngineCPUUtilization"
	IdleMetricNameCacheHits                      IdleMetricName = "CacheHits"
	IdleMetricNameCacheMisses                    IdleMetricName = "CacheMisses"
	IdleMetricNameKeyspaceHits                   IdleMetricName = "KeyspaceHits"
	IdleMetricNameKeyspaceMisses                 IdleMetricName = "KeyspaceMisses"
	IdleMetricNameIsIdle                         IdleMetricName = "IsIdle"
	IdleMetricNameUserConnected                  IdleMetricName = "UserConnected"
	IdleMetricNameInvocations                    IdleMetricName = "Invocations"
	IdleMetricNameGetTypeCmds                    IdleMetricName = "GetTypeCmds"
	IdleMetricNameSetTypeCmds                    IdleMetricName = "SetTypeCmds"
	IdleMetricNameElastiCacheProcessingUnits     IdleMetricName = "ElastiCacheProcessingUnits"
	IdleMetricNameCurrConnections                IdleMetricName = "CurrConnections"
)

// Values returns all known values for IdleMetricName. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (IdleMetricName) Values() []IdleMetricName {
	return []IdleMetricName{
		"CPU",
		"Memory",
		"NetworkOutBytesPerSecond",
		"NetworkInBytesPerSecond",
		"DatabaseConnections",
		"EBSVolumeReadIOPS",
		"EBSVolumeWriteIOPS",
		"VolumeReadOpsPerSecond",
		"VolumeWriteOpsPerSecond",
		"ActiveConnectionCount",
		"PacketsInFromSource",
		"PacketsInFromDestination",
		"ConsumedReadCapacityUnits",
		"ConsumedWriteCapacityUnits",
		"ConsumedChangeDataCaptureUnits",
		"NewConnections",
		"EngineCPUUtilization",
		"CacheHits",
		"CacheMisses",
		"KeyspaceHits",
		"KeyspaceMisses",
		"IsIdle",
		"UserConnected",
		"Invocations",
		"GetTypeCmds",
		"SetTypeCmds",
		"ElastiCacheProcessingUnits",
		"CurrConnections",
	}
}

type IdleRecommendationFilterName string

// Enum values for IdleRecommendationFilterName
const (
	IdleRecommendationFilterNameFinding      IdleRecommendationFilterName = "Finding"
	IdleRecommendationFilterNameResourceType IdleRecommendationFilterName = "ResourceType"
)

// Values returns all known values for IdleRecommendationFilterName. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (IdleRecommendationFilterName) Values() []IdleRecommendationFilterName {
	return []IdleRecommendationFilterName{
		"Finding",
		"ResourceType",
	}
}

type IdleRecommendationResourceType string

// Enum values for IdleRecommendationResourceType
const (
	IdleRecommendationResourceTypeEc2Instance        IdleRecommendationResourceType = "EC2Instance"
	IdleRecommendationResourceTypeAutoScalingGroup   IdleRecommendationResourceType = "AutoScalingGroup"
	IdleRecommendationResourceTypeEbsVolume          IdleRecommendationResourceType = "EBSVolume"
	IdleRecommendationResourceTypeEcsService         IdleRecommendationResourceType = "ECSService"
	IdleRecommendationResourceTypeRdsDbInstance      IdleRecommendationResourceType = "RDSDBInstance"
	IdleRecommendationResourceTypeNatGateway         IdleRecommendationResourceType = "NatGateway"
	IdleRecommendationResourceTypeDynamoDbTable      IdleRecommendationResourceType = "DynamoDBTable"
	IdleRecommendationResourceTypeElastiCacheCluster IdleRecommendationResourceType = "ElastiCacheCluster"
	IdleRecommendationResourceTypeMemoryDbCluster    IdleRecommendationResourceType = "MemoryDBCluster"
	IdleRecommendationResourceTypeDocumentDbCluster  IdleRecommendationResourceType = "DocumentDBCluster"
	IdleRecommendationResourceTypeWorkspaces         IdleRecommendationResourceType = "WorkSpaces"
	IdleRecommendationResourceTypeSageMakerEndpoint  IdleRecommendationResourceType = "SageMakerEndpoint"
)

// Values returns all known values for IdleRecommendationResourceType. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (IdleRecommendationResourceType) Values() []IdleRecommendationResourceType {
	return []IdleRecommendationResourceType{
		"EC2Instance",
		"AutoScalingGroup",
		"EBSVolume",
		"ECSService",
		"RDSDBInstance",
		"NatGateway",
		"DynamoDBTable",
		"ElastiCacheCluster",
		"MemoryDBCluster",
		"DocumentDBCluster",
		"WorkSpaces",
		"SageMakerEndpoint",
	}
}

type InferredWorkloadType string

// Enum values for InferredWorkloadType
const (
	InferredWorkloadTypeAmazonEmr       InferredWorkloadType = "AmazonEmr"
	InferredWorkloadTypeApacheCassandra InferredWorkloadType = "ApacheCassandra"
	InferredWorkloadTypeApacheHadoop    InferredWorkloadType = "ApacheHadoop"
	InferredWorkloadTypeMemcached       InferredWorkloadType = "Memcached"
	InferredWorkloadTypeNginx           InferredWorkloadType = "Nginx"
	InferredWorkloadTypePostgreSql      InferredWorkloadType = "PostgreSql"
	InferredWorkloadTypeRedis           InferredWorkloadType = "Redis"
	InferredWorkloadTypeKafka           InferredWorkloadType = "Kafka"
	InferredWorkloadTypeSqlserver       InferredWorkloadType = "SQLServer"
)

// Values returns all known values for InferredWorkloadType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InferredWorkloadType) Values() []InferredWorkloadType {
	return []InferredWorkloadType{
		"AmazonEmr",
		"ApacheCassandra",
		"ApacheHadoop",
		"Memcached",
		"Nginx",
		"PostgreSql",
		"Redis",
		"Kafka",
		"SQLServer",
	}
}

type InferredWorkloadTypesPreference string

// Enum values for InferredWorkloadTypesPreference
const (
	InferredWorkloadTypesPreferenceActive   InferredWorkloadTypesPreference = "Active"
	InferredWorkloadTypesPreferenceInactive InferredWorkloadTypesPreference = "Inactive"
)

// Values returns all known values for InferredWorkloadTypesPreference. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InferredWorkloadTypesPreference) Values() []InferredWorkloadTypesPreference {
	return []InferredWorkloadTypesPreference{
		"Active",
		"Inactive",
	}
}

type InstanceIdle string

// Enum values for InstanceIdle
const (
	InstanceIdleTrue  InstanceIdle = "True"
	InstanceIdleFalse InstanceIdle = "False"
)

// Values returns all known values for InstanceIdle. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstanceIdle) Values() []InstanceIdle {
	return []InstanceIdle{
		"True",
		"False",
	}
}

type InstanceRecommendationFindingReasonCode string

// Enum values for InstanceRecommendationFindingReasonCode
const (
	InstanceRecommendationFindingReasonCodeCpuOverProvisioned               InstanceRecommendationFindingReasonCode = "CPUOverprovisioned"
	InstanceRecommendationFindingReasonCodeCpuUnderProvisioned              InstanceRecommendationFindingReasonCode = "CPUUnderprovisioned"
	InstanceRecommendationFindingReasonCodeMemoryOverProvisioned            InstanceRecommendationFindingReasonCode = "MemoryOverprovisioned"
	InstanceRecommendationFindingReasonCodeMemoryUnderProvisioned           InstanceRecommendationFindingReasonCode = "MemoryUnderprovisioned"
	InstanceRecommendationFindingReasonCodeEbsThroughputOverProvisioned     InstanceRecommendationFindingReasonCode = "EBSThroughputOverprovisioned"
	InstanceRecommendationFindingReasonCodeEbsThroughputUnderProvisioned    InstanceRecommendationFindingReasonCode = "EBSThroughputUnderprovisioned"
	InstanceRecommendationFindingReasonCodeEbsIopsOverProvisioned           InstanceRecommendationFindingReasonCode = "EBSIOPSOverprovisioned"
	InstanceRecommendationFindingReasonCodeEbsIopsUnderProvisioned          InstanceRecommendationFindingReasonCode = "EBSIOPSUnderprovisioned"
	InstanceRecommendationFindingReasonCodeNetworkBandwidthOverProvisioned  InstanceRecommendationFindingReasonCode = "NetworkBandwidthOverprovisioned"
	InstanceRecommendationFindingReasonCodeNetworkBandwidthUnderProvisioned InstanceRecommendationFindingReasonCode = "NetworkBandwidthUnderprovisioned"
	InstanceRecommendationFindingReasonCodeNetworkPpsOverProvisioned        InstanceRecommendationFindingReasonCode = "NetworkPPSOverprovisioned"
	InstanceRecommendationFindingReasonCodeNetworkPpsUnderProvisioned       InstanceRecommendationFindingReasonCode = "NetworkPPSUnderprovisioned"
	InstanceRecommendationFindingReasonCodeDiskIopsOverProvisioned          InstanceRecommendationFindingReasonCode = "DiskIOPSOverprovisioned"
	InstanceRecommendationFindingReasonCodeDiskIopsUnderProvisioned         InstanceRecommendationFindingReasonCode = "DiskIOPSUnderprovisioned"
	InstanceRecommendationFindingReasonCodeDiskThroughputOverProvisioned    InstanceRecommendationFindingReasonCode = "DiskThroughputOverprovisioned"
	InstanceRecommendationFindingReasonCodeDiskThroughputUnderProvisioned   InstanceRecommendationFindingReasonCode = "DiskThroughputUnderprovisioned"
	InstanceRecommendationFindingReasonCodeGpuUnderProvisioned              InstanceRecommendationFindingReasonCode = "GPUUnderprovisioned"
	InstanceRecommendationFindingReasonCodeGpuOverProvisioned               InstanceRecommendationFindingReasonCode = "GPUOverprovisioned"
	InstanceRecommendationFindingReasonCodeGpuMemoryUnderProvisioned        InstanceRecommendationFindingReasonCode = "GPUMemoryUnderprovisioned"
	InstanceRecommendationFindingReasonCodeGpuMemoryOverProvisioned         InstanceRecommendationFindingReasonCode = "GPUMemoryOverprovisioned"
)

// Values returns all known values for InstanceRecommendationFindingReasonCode.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstanceRecommendationFindingReasonCode) Values() []InstanceRecommendationFindingReasonCode {
	return []InstanceRecommendationFindingReasonCode{
		"CPUOverprovisioned",
		"CPUUnderprovisioned",
		"MemoryOverprovisioned",
		"MemoryUnderprovisioned",
		"EBSThroughputOverprovisioned",
		"EBSThroughputUnderprovisioned",
		"EBSIOPSOverprovisioned",
		"EBSIOPSUnderprovisioned",
		"NetworkBandwidthOverprovisioned",
		"NetworkBandwidthUnderprovisioned",
		"NetworkPPSOverprovisioned",
		"NetworkPPSUnderprovisioned",
		"DiskIOPSOverprovisioned",
		"DiskIOPSUnderprovisioned",
		"DiskThroughputOverprovisioned",
		"DiskThroughputUnderprovisioned",
		"GPUUnderprovisioned",
		"GPUOverprovisioned",
		"GPUMemoryUnderprovisioned",
		"GPUMemoryOverprovisioned",
	}
}

type InstanceSavingsEstimationModeSource string

// Enum values for InstanceSavingsEstimationModeSource
const (
	InstanceSavingsEstimationModeSourcePublicPricing           InstanceSavingsEstimationModeSource = "PublicPricing"
	InstanceSavingsEstimationModeSourceCostExplorerRightsizing InstanceSavingsEstimationModeSource = "CostExplorerRightsizing"
	InstanceSavingsEstimationModeSourceCostOptimizationHub     InstanceSavingsEstimationModeSource = "CostOptimizationHub"
)

// Values returns all known values for InstanceSavingsEstimationModeSource. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstanceSavingsEstimationModeSource) Values() []InstanceSavingsEstimationModeSource {
	return []InstanceSavingsEstimationModeSource{
		"PublicPricing",
		"CostExplorerRightsizing",
		"CostOptimizationHub",
	}
}

type InstanceState string

// Enum values for InstanceState
const (
	InstanceStatePending      InstanceState = "pending"
	InstanceStateRunning      InstanceState = "running"
	InstanceStateShuttingDown InstanceState = "shutting-down"
	InstanceStateTerminated   InstanceState = "terminated"
	InstanceStateStopping     InstanceState = "stopping"
	InstanceStateStopped      InstanceState = "stopped"
)

// Values returns all known values for InstanceState. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InstanceState) Values() []InstanceState {
	return []InstanceState{
		"pending",
		"running",
		"shutting-down",
		"terminated",
		"stopping",
		"stopped",
	}
}

type JobFilterName string

// Enum values for JobFilterName
const (
	JobFilterNameResourceType JobFilterName = "ResourceType"
	JobFilterNameJobStatus    JobFilterName = "JobStatus"
)

// Values returns all known values for JobFilterName. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (JobFilterName) Values() []JobFilterName {
	return []JobFilterName{
		"ResourceType",
		"JobStatus",
	}
}

type JobStatus string

// Enum values for JobStatus
const (
	JobStatusQueued     JobStatus = "Queued"
	JobStatusInProgress JobStatus = "InProgress"
	JobStatusComplete   JobStatus = "Complete"
	JobStatusFailed     JobStatus = "Failed"
)

// Values returns all known values for JobStatus. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (JobStatus) Values() []JobStatus {
	return []JobStatus{
		"Queued",
		"InProgress",
		"Complete",
		"Failed",
	}
}

type LambdaFunctionMemoryMetricName string

// Enum values for LambdaFunctionMemoryMetricName
const (
	LambdaFunctionMemoryMetricNameDuration LambdaFunctionMemoryMetricName = "Duration"
)

// Values returns all known values for LambdaFunctionMemoryMetricName. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LambdaFunctionMemoryMetricName) Values() []LambdaFunctionMemoryMetricName {
	return []LambdaFunctionMemoryMetricName{
		"Duration",
	}
}

type LambdaFunctionMemoryMetricStatistic string

// Enum values for LambdaFunctionMemoryMetricStatistic
const (
	LambdaFunctionMemoryMetricStatisticLowerBound LambdaFunctionMemoryMetricStatistic = "LowerBound"
	LambdaFunctionMemoryMetricStatisticUpperBound LambdaFunctionMemoryMetricStatistic = "UpperBound"
	LambdaFunctionMemoryMetricStatisticExpected   LambdaFunctionMemoryMetricStatistic = "Expected"
)

// Values returns all known values for LambdaFunctionMemoryMetricStatistic. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LambdaFunctionMemoryMetricStatistic) Values() []LambdaFunctionMemoryMetricStatistic {
	return []LambdaFunctionMemoryMetricStatistic{
		"LowerBound",
		"UpperBound",
		"Expected",
	}
}

type LambdaFunctionMetricName string

// Enum values for LambdaFunctionMetricName
const (
	LambdaFunctionMetricNameDuration LambdaFunctionMetricName = "Duration"
	LambdaFunctionMetricNameMemory   LambdaFunctionMetricName = "Memory"
)

// Values returns all known values for LambdaFunctionMetricName. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LambdaFunctionMetricName) Values() []LambdaFunctionMetricName {
	return []LambdaFunctionMetricName{
		"Duration",
		"Memory",
	}
}

type LambdaFunctionMetricStatistic string

// Enum values for LambdaFunctionMetricStatistic
const (
	LambdaFunctionMetricStatisticMaximum LambdaFunctionMetricStatistic = "Maximum"
	LambdaFunctionMetricStatisticAverage LambdaFunctionMetricStatistic = "Average"
)

// Values returns all known values for LambdaFunctionMetricStatistic. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LambdaFunctionMetricStatistic) Values() []LambdaFunctionMetricStatistic {
	return []LambdaFunctionMetricStatistic{
		"Maximum",
		"Average",
	}
}

type LambdaFunctionRecommendationFilterName string

// Enum values for LambdaFunctionRecommendationFilterName
const (
	LambdaFunctionRecommendationFilterNameFinding           LambdaFunctionRecommendationFilterName = "Finding"
	LambdaFunctionRecommendationFilterNameFindingReasonCode LambdaFunctionRecommendationFilterName = "FindingReasonCode"
)

// Values returns all known values for LambdaFunctionRecommendationFilterName.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LambdaFunctionRecommendationFilterName) Values() []LambdaFunctionRecommendationFilterName {
	return []LambdaFunctionRecommendationFilterName{
		"Finding",
		"FindingReasonCode",
	}
}

type LambdaFunctionRecommendationFinding string

// Enum values for LambdaFunctionRecommendationFinding
const (
	LambdaFunctionRecommendationFindingOptimized    LambdaFunctionRecommendationFinding = "Optimized"
	LambdaFunctionRecommendationFindingNotOptimized LambdaFunctionRecommendationFinding = "NotOptimized"
	LambdaFunctionRecommendationFindingUnavailable  LambdaFunctionRecommendationFinding = "Unavailable"
)

// Values returns all known values for LambdaFunctionRecommendationFinding. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LambdaFunctionRecommendationFinding) Values() []LambdaFunctionRecommendationFinding {
	return []LambdaFunctionRecommendationFinding{
		"Optimized",
		"NotOptimized",
		"Unavailable",
	}
}

type LambdaFunctionRecommendationFindingReasonCode string

// Enum values for LambdaFunctionRecommendationFindingReasonCode
const (
	LambdaFunctionRecommendationFindingReasonCodeMemoryOverProvisioned  LambdaFunctionRecommendationFindingReasonCode = "MemoryOverprovisioned"
	LambdaFunctionRecommendationFindingReasonCodeMemoryUnderProvisioned LambdaFunctionRecommendationFindingReasonCode = "MemoryUnderprovisioned"
	LambdaFunctionRecommendationFindingReasonCodeInsufficientData       LambdaFunctionRecommendationFindingReasonCode = "InsufficientData"
	LambdaFunctionRecommendationFindingReasonCodeInconclusive           LambdaFunctionRecommendationFindingReasonCode = "Inconclusive"
)

// Values returns all known values for
// LambdaFunctionRecommendationFindingReasonCode. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LambdaFunctionRecommendationFindingReasonCode) Values() []LambdaFunctionRecommendationFindingReasonCode {
	return []LambdaFunctionRecommendationFindingReasonCode{
		"MemoryOverprovisioned",
		"MemoryUnderprovisioned",
		"InsufficientData",
		"Inconclusive",
	}
}

type LambdaSavingsEstimationModeSource string

// Enum values for LambdaSavingsEstimationModeSource
const (
	LambdaSavingsEstimationModeSourcePublicPricing           LambdaSavingsEstimationModeSource = "PublicPricing"
	LambdaSavingsEstimationModeSourceCostExplorerRightsizing LambdaSavingsEstimationModeSource = "CostExplorerRightsizing"
	LambdaSavingsEstimationModeSourceCostOptimizationHub     LambdaSavingsEstimationModeSource = "CostOptimizationHub"
)

// Values returns all known values for LambdaSavingsEstimationModeSource. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LambdaSavingsEstimationModeSource) Values() []LambdaSavingsEstimationModeSource {
	return []LambdaSavingsEstimationModeSource{
		"PublicPricing",
		"CostExplorerRightsizing",
		"CostOptimizationHub",
	}
}

type LicenseEdition string

// Enum values for LicenseEdition
const (
	LicenseEditionEnterprise            LicenseEdition = "Enterprise"
	LicenseEditionStandard              LicenseEdition = "Standard"
	LicenseEditionFree                  LicenseEdition = "Free"
	LicenseEditionNoLicenseEditionFound LicenseEdition = "NoLicenseEditionFound"
)

// Values returns all known values for LicenseEdition. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LicenseEdition) Values() []LicenseEdition {
	return []LicenseEdition{
		"Enterprise",
		"Standard",
		"Free",
		"NoLicenseEditionFound",
	}
}

type LicenseFinding string

// Enum values for LicenseFinding
const (
	LicenseFindingInsufficientMetrics LicenseFinding = "InsufficientMetrics"
	LicenseFindingOptimized           LicenseFinding = "Optimized"
	LicenseFindingNotOptimized        LicenseFinding = "NotOptimized"
)

// Values returns all known values for LicenseFinding. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LicenseFinding) Values() []LicenseFinding {
	return []LicenseFinding{
		"InsufficientMetrics",
		"Optimized",
		"NotOptimized",
	}
}

type LicenseFindingReasonCode string

// Enum values for LicenseFindingReasonCode
const (
	LicenseFindingReasonCodeCwAppInsightsDisabled  LicenseFindingReasonCode = "InvalidCloudWatchApplicationInsightsSetup"
	LicenseFindingReasonCodeCwAppInsightsError     LicenseFindingReasonCode = "CloudWatchApplicationInsightsError"
	LicenseFindingReasonCodeLicenseOverProvisioned LicenseFindingReasonCode = "LicenseOverprovisioned"
	LicenseFindingReasonCodeOptimized              LicenseFindingReasonCode = "Optimized"
)

// Values returns all known values for LicenseFindingReasonCode. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LicenseFindingReasonCode) Values() []LicenseFindingReasonCode {
	return []LicenseFindingReasonCode{
		"InvalidCloudWatchApplicationInsightsSetup",
		"CloudWatchApplicationInsightsError",
		"LicenseOverprovisioned",
		"Optimized",
	}
}

type LicenseModel string

// Enum values for LicenseModel
const (
	LicenseModelLicenseIncluded     LicenseModel = "LicenseIncluded"
	LicenseModelBringYourOwnLicense LicenseModel = "BringYourOwnLicense"
)

// Values returns all known values for LicenseModel. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LicenseModel) Values() []LicenseModel {
	return []LicenseModel{
		"LicenseIncluded",
		"BringYourOwnLicense",
	}
}

type LicenseName string

// Enum values for LicenseName
const (
	LicenseNameSqlserver LicenseName = "SQLServer"
)

// Values returns all known values for LicenseName. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LicenseName) Values() []LicenseName {
	return []LicenseName{
		"SQLServer",
	}
}

type LicenseRecommendationFilterName string

// Enum values for LicenseRecommendationFilterName
const (
	LicenseRecommendationFilterNameLicenseFinding           LicenseRecommendationFilterName = "Finding"
	LicenseRecommendationFilterNameLicenseFindingReasonCode LicenseRecommendationFilterName = "FindingReasonCode"
	LicenseRecommendationFilterNameLicenseName              LicenseRecommendationFilterName = "LicenseName"
)

// Values returns all known values for LicenseRecommendationFilterName. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LicenseRecommendationFilterName) Values() []LicenseRecommendationFilterName {
	return []LicenseRecommendationFilterName{
		"Finding",
		"FindingReasonCode",
		"LicenseName",
	}
}

type LookBackPeriodPreference string

// Enum values for LookBackPeriodPreference
const (
	LookBackPeriodPreferenceDays14 LookBackPeriodPreference = "DAYS_14"
	LookBackPeriodPreferenceDays32 LookBackPeriodPreference = "DAYS_32"
	LookBackPeriodPreferenceDays93 LookBackPeriodPreference = "DAYS_93"
)

// Values returns all known values for LookBackPeriodPreference. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (LookBackPeriodPreference) Values() []LookBackPeriodPreference {
	return []LookBackPeriodPreference{
		"DAYS_14",
		"DAYS_32",
		"DAYS_93",
	}
}

type MetricName string

// Enum values for MetricName
const (
	MetricNameCpu                        MetricName = "Cpu"
	MetricNameMemory                     MetricName = "Memory"
	MetricNameEbsReadOpsPerSecond        MetricName = "EBS_READ_OPS_PER_SECOND"
	MetricNameEbsWriteOpsPerSecond       MetricName = "EBS_WRITE_OPS_PER_SECOND"
	MetricNameEbsReadBytesPerSecond      MetricName = "EBS_READ_BYTES_PER_SECOND"
	MetricNameEbsWriteBytesPerSecond     MetricName = "EBS_WRITE_BYTES_PER_SECOND"
	MetricNameDiskReadOpsPerSecond       MetricName = "DISK_READ_OPS_PER_SECOND"
	MetricNameDiskWriteOpsPerSecond      MetricName = "DISK_WRITE_OPS_PER_SECOND"
	MetricNameDiskReadBytesPerSecond     MetricName = "DISK_READ_BYTES_PER_SECOND"
	MetricNameDiskWriteBytesPerSecond    MetricName = "DISK_WRITE_BYTES_PER_SECOND"
	MetricNameNetworkInBytesPerSecond    MetricName = "NETWORK_IN_BYTES_PER_SECOND"
	MetricNameNetworkOutBytesPerSecond   MetricName = "NETWORK_OUT_BYTES_PER_SECOND"
	MetricNameNetworkPacketsInPerSecond  MetricName = "NETWORK_PACKETS_IN_PER_SECOND"
	MetricNameNetworkPacketsOutPerSecond MetricName = "NETWORK_PACKETS_OUT_PER_SECOND"
	MetricNameGpuPercentage              MetricName = "GPU_PERCENTAGE"
	MetricNameGpuMemoryPercentage        MetricName = "GPU_MEMORY_PERCENTAGE"
)

// Values returns all known values for MetricName. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MetricName) Values() []MetricName {
	return []MetricName{
		"Cpu",
		"Memory",
		"EBS_READ_OPS_PER_SECOND",
		"EBS_WRITE_OPS_PER_SECOND",
		"EBS_READ_BYTES_PER_SECOND",
		"EBS_WRITE_BYTES_PER_SECOND",
		"DISK_READ_OPS_PER_SECOND",
		"DISK_WRITE_OPS_PER_SECOND",
		"DISK_READ_BYTES_PER_SECOND",
		"DISK_WRITE_BYTES_PER_SECOND",
		"NETWORK_IN_BYTES_PER_SECOND",
		"NETWORK_OUT_BYTES_PER_SECOND",
		"NETWORK_PACKETS_IN_PER_SECOND",
		"NETWORK_PACKETS_OUT_PER_SECOND",
		"GPU_PERCENTAGE",
		"GPU_MEMORY_PERCENTAGE",
	}
}

type MetricSourceProvider string

// Enum values for MetricSourceProvider
const (
	MetricSourceProviderCloudWatchAppInsights MetricSourceProvider = "CloudWatchApplicationInsights"
)

// Values returns all known values for MetricSourceProvider. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MetricSourceProvider) Values() []MetricSourceProvider {
	return []MetricSourceProvider{
		"CloudWatchApplicationInsights",
	}
}

type MetricStatistic string

// Enum values for MetricStatistic
const (
	MetricStatisticMaximum MetricStatistic = "Maximum"
	MetricStatisticAverage MetricStatistic = "Average"
)

// Values returns all known values for MetricStatistic. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MetricStatistic) Values() []MetricStatistic {
	return []MetricStatistic{
		"Maximum",
		"Average",
	}
}

type MigrationEffort string

// Enum values for MigrationEffort
const (
	MigrationEffortVeryLow MigrationEffort = "VeryLow"
	MigrationEffortLow     MigrationEffort = "Low"
	MigrationEffortMedium  MigrationEffort = "Medium"
	MigrationEffortHigh    MigrationEffort = "High"
)

// Values returns all known values for MigrationEffort. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MigrationEffort) Values() []MigrationEffort {
	return []MigrationEffort{
		"VeryLow",
		"Low",
		"Medium",
		"High",
	}
}

type Order string

// Enum values for Order
const (
	OrderAsc  Order = "Asc"
	OrderDesc Order = "Desc"
)

// Values returns all known values for Order. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Order) Values() []Order {
	return []Order{
		"Asc",
		"Desc",
	}
}

type PlatformDifference string

// Enum values for PlatformDifference
const (
	PlatformDifferenceHypervisor                PlatformDifference = "Hypervisor"
	PlatformDifferenceNetworkInterface          PlatformDifference = "NetworkInterface"
	PlatformDifferenceStorageInterface          PlatformDifference = "StorageInterface"
	PlatformDifferenceInstanceStoreAvailability PlatformDifference = "InstanceStoreAvailability"
	PlatformDifferenceVirtualizationType        PlatformDifference = "VirtualizationType"
	PlatformDifferenceArchitecture              PlatformDifference = "Architecture"
)

// Values returns all known values for PlatformDifference. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PlatformDifference) Values() []PlatformDifference {
	return []PlatformDifference{
		"Hypervisor",
		"NetworkInterface",
		"StorageInterface",
		"InstanceStoreAvailability",
		"VirtualizationType",
		"Architecture",
	}
}

type PreferredResourceName string

// Enum values for PreferredResourceName
const (
	PreferredResourceNameEc2InstanceTypes PreferredResourceName = "Ec2InstanceTypes"
)

// Values returns all known values for PreferredResourceName. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PreferredResourceName) Values() []PreferredResourceName {
	return []PreferredResourceName{
		"Ec2InstanceTypes",
	}
}

type RDSCurrentInstancePerformanceRisk string

// Enum values for RDSCurrentInstancePerformanceRisk
const (
	RDSCurrentInstancePerformanceRiskVeryLow RDSCurrentInstancePerformanceRisk = "VeryLow"
	RDSCurrentInstancePerformanceRiskLow     RDSCurrentInstancePerformanceRisk = "Low"
	RDSCurrentInstancePerformanceRiskMedium  RDSCurrentInstancePerformanceRisk = "Medium"
	RDSCurrentInstancePerformanceRiskHigh    RDSCurrentInstancePerformanceRisk = "High"
)

// Values returns all known values for RDSCurrentInstancePerformanceRisk. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSCurrentInstancePerformanceRisk) Values() []RDSCurrentInstancePerformanceRisk {
	return []RDSCurrentInstancePerformanceRisk{
		"VeryLow",
		"Low",
		"Medium",
		"High",
	}
}

type RDSDBMetricName string

// Enum values for RDSDBMetricName
const (
	RDSDBMetricNameCpu                              RDSDBMetricName = "CPU"
	RDSDBMetricNameMemory                           RDSDBMetricName = "Memory"
	RDSDBMetricNameEbsVolumeStorageSpaceUtilization RDSDBMetricName = "EBSVolumeStorageSpaceUtilization"
	RDSDBMetricNameNetworkReceiveThroughput         RDSDBMetricName = "NetworkReceiveThroughput"
	RDSDBMetricNameNetworkTransmitThroughput        RDSDBMetricName = "NetworkTransmitThroughput"
	RDSDBMetricNameEbsVolumeReadIops                RDSDBMetricName = "EBSVolumeReadIOPS"
	RDSDBMetricNameEbsVolumeWriteIops               RDSDBMetricName = "EBSVolumeWriteIOPS"
	RDSDBMetricNameEbsVolumeReadThroughput          RDSDBMetricName = "EBSVolumeReadThroughput"
	RDSDBMetricNameEbsVolumeWriteThroughput         RDSDBMetricName = "EBSVolumeWriteThroughput"
	RDSDBMetricNameDatabaseConnections              RDSDBMetricName = "DatabaseConnections"
	RDSDBMetricNameStorageNetworkReceiveThroughput  RDSDBMetricName = "StorageNetworkReceiveThroughput"
	RDSDBMetricNameStorageNetworkTransmitThroughput RDSDBMetricName = "StorageNetworkTransmitThroughput"
	RDSDBMetricNameAuroraMemoryHealthState          RDSDBMetricName = "AuroraMemoryHealthState"
	RDSDBMetricNameAuroraMemoryNumDeclinedSql       RDSDBMetricName = "AuroraMemoryNumDeclinedSql"
	RDSDBMetricNameAuroraMemoryNumKillConnTotal     RDSDBMetricName = "AuroraMemoryNumKillConnTotal"
	RDSDBMetricNameAuroraMemoryNumKillQueryTotal    RDSDBMetricName = "AuroraMemoryNumKillQueryTotal"
	RDSDBMetricNameReadIopsEphemeralStorage         RDSDBMetricName = "ReadIOPSEphemeralStorage"
	RDSDBMetricNameWriteIopsEphemeralStorage        RDSDBMetricName = "WriteIOPSEphemeralStorage"
	RDSDBMetricNameVolumeReadIops                   RDSDBMetricName = "VolumeReadIOPs"
	RDSDBMetricNameVolumeBytesUsed                  RDSDBMetricName = "VolumeBytesUsed"
	RDSDBMetricNameVolumeWriteIops                  RDSDBMetricName = "VolumeWriteIOPs"
)

// Values returns all known values for RDSDBMetricName. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSDBMetricName) Values() []RDSDBMetricName {
	return []RDSDBMetricName{
		"CPU",
		"Memory",
		"EBSVolumeStorageSpaceUtilization",
		"NetworkReceiveThroughput",
		"NetworkTransmitThroughput",
		"EBSVolumeReadIOPS",
		"EBSVolumeWriteIOPS",
		"EBSVolumeReadThroughput",
		"EBSVolumeWriteThroughput",
		"DatabaseConnections",
		"StorageNetworkReceiveThroughput",
		"StorageNetworkTransmitThroughput",
		"AuroraMemoryHealthState",
		"AuroraMemoryNumDeclinedSql",
		"AuroraMemoryNumKillConnTotal",
		"AuroraMemoryNumKillQueryTotal",
		"ReadIOPSEphemeralStorage",
		"WriteIOPSEphemeralStorage",
		"VolumeReadIOPs",
		"VolumeBytesUsed",
		"VolumeWriteIOPs",
	}
}

type RDSDBMetricStatistic string

// Enum values for RDSDBMetricStatistic
const (
	RDSDBMetricStatisticMaximum RDSDBMetricStatistic = "Maximum"
	RDSDBMetricStatisticMinimum RDSDBMetricStatistic = "Minimum"
	RDSDBMetricStatisticAverage RDSDBMetricStatistic = "Average"
)

// Values returns all known values for RDSDBMetricStatistic. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSDBMetricStatistic) Values() []RDSDBMetricStatistic {
	return []RDSDBMetricStatistic{
		"Maximum",
		"Minimum",
		"Average",
	}
}

type RDSDBRecommendationFilterName string

// Enum values for RDSDBRecommendationFilterName
const (
	RDSDBRecommendationFilterNameInstanceFinding           RDSDBRecommendationFilterName = "InstanceFinding"
	RDSDBRecommendationFilterNameInstanceFindingReasonCode RDSDBRecommendationFilterName = "InstanceFindingReasonCode"
	RDSDBRecommendationFilterNameStorageFinding            RDSDBRecommendationFilterName = "StorageFinding"
	RDSDBRecommendationFilterNameStorageFindingReasonCode  RDSDBRecommendationFilterName = "StorageFindingReasonCode"
	RDSDBRecommendationFilterNameIdle                      RDSDBRecommendationFilterName = "Idle"
)

// Values returns all known values for RDSDBRecommendationFilterName. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSDBRecommendationFilterName) Values() []RDSDBRecommendationFilterName {
	return []RDSDBRecommendationFilterName{
		"InstanceFinding",
		"InstanceFindingReasonCode",
		"StorageFinding",
		"StorageFindingReasonCode",
		"Idle",
	}
}

type RDSEstimatedMonthlyVolumeIOPsCostVariation string

// Enum values for RDSEstimatedMonthlyVolumeIOPsCostVariation
const (
	RDSEstimatedMonthlyVolumeIOPsCostVariationNone   RDSEstimatedMonthlyVolumeIOPsCostVariation = "None"
	RDSEstimatedMonthlyVolumeIOPsCostVariationLow    RDSEstimatedMonthlyVolumeIOPsCostVariation = "Low"
	RDSEstimatedMonthlyVolumeIOPsCostVariationMedium RDSEstimatedMonthlyVolumeIOPsCostVariation = "Medium"
	RDSEstimatedMonthlyVolumeIOPsCostVariationHigh   RDSEstimatedMonthlyVolumeIOPsCostVariation = "High"
)

// Values returns all known values for RDSEstimatedMonthlyVolumeIOPsCostVariation.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSEstimatedMonthlyVolumeIOPsCostVariation) Values() []RDSEstimatedMonthlyVolumeIOPsCostVariation {
	return []RDSEstimatedMonthlyVolumeIOPsCostVariation{
		"None",
		"Low",
		"Medium",
		"High",
	}
}

type RDSInstanceFinding string

// Enum values for RDSInstanceFinding
const (
	RDSInstanceFindingOptimized        RDSInstanceFinding = "Optimized"
	RDSInstanceFindingUnderProvisioned RDSInstanceFinding = "Underprovisioned"
	RDSInstanceFindingOverProvisioned  RDSInstanceFinding = "Overprovisioned"
)

// Values returns all known values for RDSInstanceFinding. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSInstanceFinding) Values() []RDSInstanceFinding {
	return []RDSInstanceFinding{
		"Optimized",
		"Underprovisioned",
		"Overprovisioned",
	}
}

type RDSInstanceFindingReasonCode string

// Enum values for RDSInstanceFindingReasonCode
const (
	RDSInstanceFindingReasonCodeCpuOverProvisioned                       RDSInstanceFindingReasonCode = "CPUOverprovisioned"
	RDSInstanceFindingReasonCodeNetworkBandwidthOverProvisioned          RDSInstanceFindingReasonCode = "NetworkBandwidthOverprovisioned"
	RDSInstanceFindingReasonCodeEbsIopsOverProvisioned                   RDSInstanceFindingReasonCode = "EBSIOPSOverprovisioned"
	RDSInstanceFindingReasonCodeEbsIopsUnderProvisioned                  RDSInstanceFindingReasonCode = "EBSIOPSUnderprovisioned"
	RDSInstanceFindingReasonCodeEbsThroughputOverProvisioned             RDSInstanceFindingReasonCode = "EBSThroughputOverprovisioned"
	RDSInstanceFindingReasonCodeCpuUnderProvisioned                      RDSInstanceFindingReasonCode = "CPUUnderprovisioned"
	RDSInstanceFindingReasonCodeNetworkBandwidthUnderProvisioned         RDSInstanceFindingReasonCode = "NetworkBandwidthUnderprovisioned"
	RDSInstanceFindingReasonCodeEbsThroughputUnderProvisioned            RDSInstanceFindingReasonCode = "EBSThroughputUnderprovisioned"
	RDSInstanceFindingReasonCodeNewGenerationDbInstanceClassAvailable    RDSInstanceFindingReasonCode = "NewGenerationDBInstanceClassAvailable"
	RDSInstanceFindingReasonCodeNewEngineVersionAvailable                RDSInstanceFindingReasonCode = "NewEngineVersionAvailable"
	RDSInstanceFindingReasonCodeDbClusterWriterUnderProvisioned          RDSInstanceFindingReasonCode = "DBClusterWriterUnderprovisioned"
	RDSInstanceFindingReasonCodeMemoryUnderProvisioned                   RDSInstanceFindingReasonCode = "MemoryUnderprovisioned"
	RDSInstanceFindingReasonCodeInstanceStorageReadIopsUnderProvisioned  RDSInstanceFindingReasonCode = "InstanceStorageReadIOPSUnderprovisioned"
	RDSInstanceFindingReasonCodeInstanceStorageWriteIopsUnderProvisioned RDSInstanceFindingReasonCode = "InstanceStorageWriteIOPSUnderprovisioned"
)

// Values returns all known values for RDSInstanceFindingReasonCode. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSInstanceFindingReasonCode) Values() []RDSInstanceFindingReasonCode {
	return []RDSInstanceFindingReasonCode{
		"CPUOverprovisioned",
		"NetworkBandwidthOverprovisioned",
		"EBSIOPSOverprovisioned",
		"EBSIOPSUnderprovisioned",
		"EBSThroughputOverprovisioned",
		"CPUUnderprovisioned",
		"NetworkBandwidthUnderprovisioned",
		"EBSThroughputUnderprovisioned",
		"NewGenerationDBInstanceClassAvailable",
		"NewEngineVersionAvailable",
		"DBClusterWriterUnderprovisioned",
		"MemoryUnderprovisioned",
		"InstanceStorageReadIOPSUnderprovisioned",
		"InstanceStorageWriteIOPSUnderprovisioned",
	}
}

type RDSSavingsEstimationModeSource string

// Enum values for RDSSavingsEstimationModeSource
const (
	RDSSavingsEstimationModeSourcePublicPricing           RDSSavingsEstimationModeSource = "PublicPricing"
	RDSSavingsEstimationModeSourceCostExplorerRightsizing RDSSavingsEstimationModeSource = "CostExplorerRightsizing"
	RDSSavingsEstimationModeSourceCostOptimizationHub     RDSSavingsEstimationModeSource = "CostOptimizationHub"
)

// Values returns all known values for RDSSavingsEstimationModeSource. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSSavingsEstimationModeSource) Values() []RDSSavingsEstimationModeSource {
	return []RDSSavingsEstimationModeSource{
		"PublicPricing",
		"CostExplorerRightsizing",
		"CostOptimizationHub",
	}
}

type RDSStorageFinding string

// Enum values for RDSStorageFinding
const (
	RDSStorageFindingOptimized        RDSStorageFinding = "Optimized"
	RDSStorageFindingUnderProvisioned RDSStorageFinding = "Underprovisioned"
	RDSStorageFindingOverProvisioned  RDSStorageFinding = "Overprovisioned"
	RDSStorageFindingNotOptimized     RDSStorageFinding = "NotOptimized"
)

// Values returns all known values for RDSStorageFinding. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSStorageFinding) Values() []RDSStorageFinding {
	return []RDSStorageFinding{
		"Optimized",
		"Underprovisioned",
		"Overprovisioned",
		"NotOptimized",
	}
}

type RDSStorageFindingReasonCode string

// Enum values for RDSStorageFindingReasonCode
const (
	RDSStorageFindingReasonCodeEbsVolumeAllocatedStorageUnderProvisioned RDSStorageFindingReasonCode = "EBSVolumeAllocatedStorageUnderprovisioned"
	RDSStorageFindingReasonCodeEbsVolumeThroughputUnderProvisioned       RDSStorageFindingReasonCode = "EBSVolumeThroughputUnderprovisioned"
	RDSStorageFindingReasonCodeEbsVolumeIopsOverProvisioned              RDSStorageFindingReasonCode = "EBSVolumeIOPSOverprovisioned"
	RDSStorageFindingReasonCodeEbsVolumeThroughputOverProvisioned        RDSStorageFindingReasonCode = "EBSVolumeThroughputOverprovisioned"
	RDSStorageFindingReasonCodeNewGenerationStorageTypeAvailable         RDSStorageFindingReasonCode = "NewGenerationStorageTypeAvailable"
	RDSStorageFindingReasonCodeDbClusterStorageOptionAvailable           RDSStorageFindingReasonCode = "DBClusterStorageOptionAvailable"
	RDSStorageFindingReasonCodeDbClusterStorageSavingsAvailable          RDSStorageFindingReasonCode = "DBClusterStorageSavingsAvailable"
)

// Values returns all known values for RDSStorageFindingReasonCode. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RDSStorageFindingReasonCode) Values() []RDSStorageFindingReasonCode {
	return []RDSStorageFindingReasonCode{
		"EBSVolumeAllocatedStorageUnderprovisioned",
		"EBSVolumeThroughputUnderprovisioned",
		"EBSVolumeIOPSOverprovisioned",
		"EBSVolumeThroughputOverprovisioned",
		"NewGenerationStorageTypeAvailable",
		"DBClusterStorageOptionAvailable",
		"DBClusterStorageSavingsAvailable",
	}
}

type RecommendationPreferenceName string

// Enum values for RecommendationPreferenceName
const (
	RecommendationPreferenceNameEnhancedInfrastructureMetrics RecommendationPreferenceName = "EnhancedInfrastructureMetrics"
	RecommendationPreferenceNameInferredWorkloadTypes         RecommendationPreferenceName = "InferredWorkloadTypes"
	RecommendationPreferenceNameExternalMetricsPreference     RecommendationPreferenceName = "ExternalMetricsPreference"
	RecommendationPreferenceNameLookbackPeriodPreference      RecommendationPreferenceName = "LookBackPeriodPreference"
	RecommendationPreferenceNamePreferredResources            RecommendationPreferenceName = "PreferredResources"
	RecommendationPreferenceNameUtilizationPreferences        RecommendationPreferenceName = "UtilizationPreferences"
)

// Values returns all known values for RecommendationPreferenceName. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RecommendationPreferenceName) Values() []RecommendationPreferenceName {
	return []RecommendationPreferenceName{
		"EnhancedInfrastructureMetrics",
		"InferredWorkloadTypes",
		"ExternalMetricsPreference",
		"LookBackPeriodPreference",
		"PreferredResources",
		"UtilizationPreferences",
	}
}

type RecommendationSourceType string

// Enum values for RecommendationSourceType
const (
	RecommendationSourceTypeEc2Instance            RecommendationSourceType = "Ec2Instance"
	RecommendationSourceTypeAutoScalingGroup       RecommendationSourceType = "AutoScalingGroup"
	RecommendationSourceTypeEbsVolume              RecommendationSourceType = "EbsVolume"
	RecommendationSourceTypeLambdaFunction         RecommendationSourceType = "LambdaFunction"
	RecommendationSourceTypeEcsService             RecommendationSourceType = "EcsService"
	RecommendationSourceTypeLicense                RecommendationSourceType = "License"
	RecommendationSourceTypeRdsDbInstance          RecommendationSourceType = "RdsDBInstance"
	RecommendationSourceTypeRdsDbInstanceStorage   RecommendationSourceType = "RdsDBInstanceStorage"
	RecommendationSourceTypeAuroraDbClusterStorage RecommendationSourceType = "AuroraDBClusterStorage"
	RecommendationSourceTypeNatGateway             RecommendationSourceType = "NatGateway"
	RecommendationSourceTypeDynamoDbTable          RecommendationSourceType = "DynamoDBTable"
	RecommendationSourceTypeElastiCacheCluster     RecommendationSourceType = "ElastiCacheCluster"
	RecommendationSourceTypeMemoryDbCluster        RecommendationSourceType = "MemoryDBCluster"
	RecommendationSourceTypeDocumentDbCluster      RecommendationSourceType = "DocumentDBCluster"
	RecommendationSourceTypeWorkspaces             RecommendationSourceType = "WorkSpaces"
	RecommendationSourceTypeSageMakerEndpoint      RecommendationSourceType = "SageMakerEndpoint"
)

// Values returns all known values for RecommendationSourceType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RecommendationSourceType) Values() []RecommendationSourceType {
	return []RecommendationSourceType{
		"Ec2Instance",
		"AutoScalingGroup",
		"EbsVolume",
		"LambdaFunction",
		"EcsService",
		"License",
		"RdsDBInstance",
		"RdsDBInstanceStorage",
		"AuroraDBClusterStorage",
		"NatGateway",
		"DynamoDBTable",
		"ElastiCacheCluster",
		"MemoryDBCluster",
		"DocumentDBCluster",
		"WorkSpaces",
		"SageMakerEndpoint",
	}
}

type ResourceType string

// Enum values for ResourceType
const (
	ResourceTypeEc2Instance            ResourceType = "Ec2Instance"
	ResourceTypeAutoScalingGroup       ResourceType = "AutoScalingGroup"
	ResourceTypeEbsVolume              ResourceType = "EbsVolume"
	ResourceTypeLambdaFunction         ResourceType = "LambdaFunction"
	ResourceTypeNotApplicable          ResourceType = "NotApplicable"
	ResourceTypeEcsService             ResourceType = "EcsService"
	ResourceTypeLicense                ResourceType = "License"
	ResourceTypeRdsDbInstance          ResourceType = "RdsDBInstance"
	ResourceTypeAuroraDbClusterStorage ResourceType = "AuroraDBClusterStorage"
	ResourceTypeIdle                   ResourceType = "Idle"
)

// Values returns all known values for ResourceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ResourceType) Values() []ResourceType {
	return []ResourceType{
		"Ec2Instance",
		"AutoScalingGroup",
		"EbsVolume",
		"LambdaFunction",
		"NotApplicable",
		"EcsService",
		"License",
		"RdsDBInstance",
		"AuroraDBClusterStorage",
		"Idle",
	}
}

type SavingsEstimationMode string

// Enum values for SavingsEstimationMode
const (
	SavingsEstimationModeAfterDiscounts  SavingsEstimationMode = "AfterDiscounts"
	SavingsEstimationModeBeforeDiscounts SavingsEstimationMode = "BeforeDiscounts"
)

// Values returns all known values for SavingsEstimationMode. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SavingsEstimationMode) Values() []SavingsEstimationMode {
	return []SavingsEstimationMode{
		"AfterDiscounts",
		"BeforeDiscounts",
	}
}

type ScopeName string

// Enum values for ScopeName
const (
	ScopeNameOrganization ScopeName = "Organization"
	ScopeNameAccountId    ScopeName = "AccountId"
	ScopeNameResourceArn  ScopeName = "ResourceArn"
)

// Values returns all known values for ScopeName. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ScopeName) Values() []ScopeName {
	return []ScopeName{
		"Organization",
		"AccountId",
		"ResourceArn",
	}
}

type Status string

// Enum values for Status
const (
	StatusActive   Status = "Active"
	StatusInactive Status = "Inactive"
	StatusPending  Status = "Pending"
	StatusFailed   Status = "Failed"
)

// Values returns all known values for Status. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Status) Values() []Status {
	return []Status{
		"Active",
		"Inactive",
		"Pending",
		"Failed",
	}
}
